summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorRuslan Zakharov <r.zakharov@samsung.com>2017-09-13 13:06:50 +0300
committerRuslan Zakharov <r.zakharov@samsung.com>2017-10-03 15:04:34 +0300
commitdcd7c5f6d03f56dd30a58f99ae7bec6bd4520cef (patch)
tree5301647ce596932e714683c5e2e77f389542a4a7
parentd172f3efabbe618f2edb7462080931cf20c473a4 (diff)
downloadcall-ui-dcd7c5f6d03f56dd30a58f99ae7bec6bd4520cef.tar.gz
call-ui-dcd7c5f6d03f56dd30a58f99ae7bec6bd4520cef.tar.bz2
call-ui-dcd7c5f6d03f56dd30a58f99ae7bec6bd4520cef.zip
TizenRefApp-9270 Refactor Call app structure based on project structure document
Project structure was refactored, namespaces was renamed, unused resources was deleted Change-Id: I8bd1f2aaed69d898049f3e010a5b2b10bf517c76
-rw-r--r--CallApp.Tizen/App.xaml10
-rw-r--r--CallApp.Tizen/App.xaml.cs (renamed from CallApp.Tizen/CallApp.cs)9
-rw-r--r--CallApp.Tizen/Call/Controls/MergeSwapPanel.xaml17
-rw-r--r--CallApp.Tizen/Call/Themes/CallTheme.xaml15
-rw-r--r--CallApp.Tizen/Call/View/ConferenceCallManagePage.xaml (renamed from CallApp.Tizen/Call/Pages/ConferenceCallManagePage.xaml)21
-rw-r--r--CallApp.Tizen/Call/View/ConferenceCallManagePage.xaml.cs (renamed from CallApp.Tizen/Call/Pages/ConferenceCallManagePage.xaml.cs)2
-rw-r--r--CallApp.Tizen/Call/View/Controls/AnimatedCircleButton.xaml (renamed from CallApp.Tizen/Call/Controls/AnimatedCircleButton.xaml)22
-rw-r--r--CallApp.Tizen/Call/View/Controls/AnimatedCircleButton.xaml.cs (renamed from CallApp.Tizen/Call/Controls/AnimatedCircleButton.xaml.cs)2
-rw-r--r--CallApp.Tizen/Call/View/Controls/CallHandlingPanel.xaml (renamed from CallApp.Tizen/Call/Controls/CallHandlingPanel.xaml)45
-rw-r--r--CallApp.Tizen/Call/View/Controls/CallHandlingPanel.xaml.cs (renamed from CallApp.Tizen/Call/Controls/CallHandlingPanel.xaml.cs)2
-rw-r--r--CallApp.Tizen/Call/View/Controls/ConferenceCallManageList.xaml (renamed from CallApp.Tizen/Call/Controls/ConferenceCallManageList.xaml)18
-rw-r--r--CallApp.Tizen/Call/View/Controls/ConferenceCallManageList.xaml.cs (renamed from CallApp.Tizen/Call/Controls/ConferenceCallManageList.xaml.cs)2
-rw-r--r--CallApp.Tizen/Call/View/Controls/ContactInfoPanel.xaml (renamed from CallApp.Tizen/Call/Controls/ContactInfoPanel.xaml)73
-rw-r--r--CallApp.Tizen/Call/View/Controls/ContactInfoPanel.xaml.cs (renamed from CallApp.Tizen/Call/Controls/ContactInfoPanel.xaml.cs)2
-rw-r--r--CallApp.Tizen/Call/View/Controls/FlatButton.xaml (renamed from CallApp.Tizen/Call/Controls/FlatButton.xaml)28
-rw-r--r--CallApp.Tizen/Call/View/Controls/FlatButton.xaml.cs (renamed from CallApp.Tizen/Call/Controls/FlatButton.xaml.cs)2
-rw-r--r--CallApp.Tizen/Call/View/Controls/FlatCheckbox.xaml (renamed from CallApp.Tizen/Call/Controls/FlatCheckbox.xaml)22
-rw-r--r--CallApp.Tizen/Call/View/Controls/FlatCheckbox.xaml.cs (renamed from CallApp.Tizen/Call/Controls/FlatCheckbox.xaml.cs)2
-rw-r--r--CallApp.Tizen/Call/View/Controls/Keypad.xaml (renamed from CallApp.Tizen/Call/Controls/Keypad.xaml)36
-rw-r--r--CallApp.Tizen/Call/View/Controls/Keypad.xaml.cs (renamed from CallApp.Tizen/Call/Controls/Keypad.xaml.cs)2
-rw-r--r--CallApp.Tizen/Call/View/Controls/KeypadButton.xaml (renamed from CallApp.Tizen/Call/Controls/KeypadButton.xaml)22
-rw-r--r--CallApp.Tizen/Call/View/Controls/KeypadButton.xaml.cs (renamed from CallApp.Tizen/Call/Controls/KeypadButton.xaml.cs)2
-rw-r--r--CallApp.Tizen/Call/View/Controls/MergeSwapPanel.xaml17
-rw-r--r--CallApp.Tizen/Call/View/Controls/MergeSwapPanel.xaml.cs (renamed from CallApp.Tizen/Call/Controls/MergeSwapPanel.xaml.cs)2
-rw-r--r--CallApp.Tizen/Call/View/Controls/MiniActiveCallPanel.xaml (renamed from CallApp.Tizen/Call/Controls/MiniActiveCallPanel.xaml)29
-rw-r--r--CallApp.Tizen/Call/View/Controls/MiniActiveCallPanel.xaml.cs (renamed from CallApp.Tizen/Call/Controls/MiniActiveCallPanel.xaml.cs)2
-rw-r--r--CallApp.Tizen/Call/View/Controls/ProximityControl.xaml (renamed from CallApp.Tizen/Call/Controls/ProximityControl.xaml)8
-rw-r--r--CallApp.Tizen/Call/View/Controls/ProximityControl.xaml.cs (renamed from CallApp.Tizen/Call/Controls/ProximityControl.xaml.cs)2
-rw-r--r--CallApp.Tizen/Call/View/Controls/RejectCallPanel.xaml (renamed from CallApp.Tizen/Call/Controls/RejectCallPanel.xaml)57
-rw-r--r--CallApp.Tizen/Call/View/Controls/RejectCallPanel.xaml.cs (renamed from CallApp.Tizen/Call/Controls/RejectCallPanel.xaml.cs)2
-rw-r--r--CallApp.Tizen/Call/View/Controls/RejectMessageList.xaml (renamed from CallApp.Tizen/Call/Controls/RejectMessageList.xaml)13
-rw-r--r--CallApp.Tizen/Call/View/Controls/RejectMessageList.xaml.cs (renamed from CallApp.Tizen/Call/Controls/RejectMessageList.xaml.cs)2
-rw-r--r--CallApp.Tizen/Call/View/Controls/Renderers/AnimatedCircleButtonRenderer.cs (renamed from CallApp.Tizen/Call/Controls/Renderers/AnimatedCircleButtonRenderer.cs)6
-rw-r--r--CallApp.Tizen/CallApp.Tizen.csproj116
-rw-r--r--CallApp.Tizen/Common/Themes/CommonTheme.xaml15
-rw-r--r--CallApp.Tizen/Common/Themes/CommonTheme.xaml.cs (renamed from CallApp.Tizen/Call/Themes/CallTheme.xaml.cs)8
-rw-r--r--CallApp.Tizen/Properties/AssemblyInfo.cs8
-rw-r--r--CallApp.Tizen/Tizen.Utility/Controls/CustomGrid.xaml (renamed from CallApp.Tizen/Common/Controls/CustomGrid.xaml)2
-rw-r--r--CallApp.Tizen/Tizen.Utility/Controls/CustomGrid.xaml.cs (renamed from CallApp.Tizen/Common/Controls/CustomGrid.xaml.cs)2
-rw-r--r--CallApp.Tizen/Tizen.Utility/Controls/CustomImage.xaml (renamed from CallApp.Tizen/Common/Controls/CustomImage.xaml)2
-rw-r--r--CallApp.Tizen/Tizen.Utility/Controls/CustomImage.xaml.cs (renamed from CallApp.Tizen/Common/Controls/CustomImage.xaml.cs)2
-rw-r--r--CallApp.Tizen/Tizen.Utility/Controls/GesturesContainer.xaml (renamed from CallApp.Tizen/Common/Controls/GesturesContainer.xaml)2
-rw-r--r--CallApp.Tizen/Tizen.Utility/Controls/GesturesContainer.xaml.cs (renamed from CallApp.Tizen/Common/Controls/GesturesContainer.xaml.cs)2
-rw-r--r--CallApp.Tizen/Tizen.Utility/Controls/Renderers/CustomImageRenderer.cs (renamed from CallApp.Tizen/Common/Controls/Renderers/CustomImageRenderer.cs)6
-rw-r--r--CallApp.Tizen/Tizen.Utility/Converters/IsNullConverter.cs (renamed from CallApp.Tizen/Common/Converters/IsNullConverter.cs)2
-rw-r--r--CallApp.Tizen/Tizen.Utility/Converters/IsStringEmptyConverter.cs (renamed from CallApp.Tizen/Common/Converters/IsStringEmptyConverter.cs)2
-rw-r--r--CallApp.Tizen/Tizen.Utility/Helpers/BaseModel.cs (renamed from CallApp.Tizen/Common/Helpers/BaseModel.cs)2
-rw-r--r--CallApp.Tizen/Tizen.Utility/Helpers/Logger.cs (renamed from CallApp.Tizen/Common/Helpers/Logger.cs)2
-rw-r--r--CallApp.Tizen/Tizen.Utility/Helpers/PageNavigator.cs (renamed from CallApp.Tizen/Common/Helpers/PageNavigator.cs)2
-rw-r--r--CallApp.Tizen/Tizen.Utility/Input/AttachedTapCommand.cs (renamed from CallApp.Tizen/Common/Input/AttachedTapCommand.cs)5
-rw-r--r--CallApp.Tizen/Tizen.Utility/Input/GesturesInput.cs (renamed from CallApp.Tizen/Common/Input/GesturesInput.cs)2
-rw-r--r--CallApp.Tizen/loc/Localization.Designer.cs (renamed from CallApp.Tizen/loc/loc.Designer.cs)219
-rw-r--r--CallApp.Tizen/loc/Localization.resx (renamed from CallApp.Tizen/loc/loc.resx)0
-rw-r--r--CallApp.Tizen/res/Call ID/168x168/call_end_photo_id_default.pngbin4754 -> 0 bytes
-rw-r--r--CallApp.Tizen/res/Call ID/348x348/call_photo_id.pngbin9511 -> 0 bytes
-rw-r--r--CallApp.Tizen/res/Call ID/348x348/call_photo_id_conference.pngbin11155 -> 0 bytes
-rw-r--r--CallApp.Tizen/res/Call ID/96x96/call_photo_id_conference.pngbin5259 -> 0 bytes
-rw-r--r--CallApp.Tizen/res/call_manage_photo_id_mask_04.pngbin17750 -> 0 bytes
58 files changed, 479 insertions, 418 deletions
diff --git a/CallApp.Tizen/App.xaml b/CallApp.Tizen/App.xaml
new file mode 100644
index 0000000..2554c9c
--- /dev/null
+++ b/CallApp.Tizen/App.xaml
@@ -0,0 +1,10 @@
+<?xml version="1.0" encoding="utf-8"?>
+<Application xmlns="http://xamarin.com/schemas/2014/forms"
+ xmlns:x="http://schemas.microsoft.com/winfx/2009/xaml"
+ x:Class="CallApp.App"
+ xmlns:CommonThemes="clr-namespace:CallApp.Tizen.Common.Themes">
+
+ <Application.Resources>
+ <ResourceDictionary MergedWith="CommonThemes:CommonTheme" />
+ </Application.Resources>
+</Application> \ No newline at end of file
diff --git a/CallApp.Tizen/CallApp.cs b/CallApp.Tizen/App.xaml.cs
index 7f86857..45e733a 100644
--- a/CallApp.Tizen/CallApp.cs
+++ b/CallApp.Tizen/App.xaml.cs
@@ -1,4 +1,4 @@
-/*
+/*
* Copyright 2017 Samsung Electronics Co., Ltd
*
* Licensed under the Flora License, Version 1.1 (the "License");
@@ -18,10 +18,15 @@ using Xamarin.Forms;
namespace CallApp
{
- public class App : Application
+ /// <summary>
+ /// Class that represents a Call mobile app
+ /// </summary>
+ public partial class App : Application
{
public App()
{
+ InitializeComponent();
+
MainPage = null;
}
diff --git a/CallApp.Tizen/Call/Controls/MergeSwapPanel.xaml b/CallApp.Tizen/Call/Controls/MergeSwapPanel.xaml
deleted file mode 100644
index 191accc..0000000
--- a/CallApp.Tizen/Call/Controls/MergeSwapPanel.xaml
+++ /dev/null
@@ -1,17 +0,0 @@
-<?xml version="1.0" encoding="UTF-8"?>
-<ContentView xmlns="http://xamarin.com/schemas/2014/forms"
- xmlns:x="http://schemas.microsoft.com/winfx/2009/xaml"
- x:Class="CallApp.Tizen.Call.Controls.MergeSwapPanel"
- xmlns:callControls="clr-namespace:CallApp.Tizen.Call.Controls"
- xmlns:loc="clr-namespace:CallApp.Tizen.loc">
-
- <StackLayout>
- <callControls:ContactInfoPanel LayoutType="Top" StatusText="{x:Static loc:loc.OnHold}"
- PrimaryText="Test" SecondaryText="Test" />
-
- <StackLayout HeightRequest="122" Orientation="Horizontal">
- <callControls:FlatButton HorizontalOptions="FillAndExpand" Image="call_multi_ic_merge.png" Text="{x:Static loc:loc.Merge}" />
- <callControls:FlatButton HorizontalOptions="FillAndExpand" Image="call_multi_ic_swap.png" Text="{x:Static loc:loc.Swap}" />
- </StackLayout>
- </StackLayout>
-</ContentView> \ No newline at end of file
diff --git a/CallApp.Tizen/Call/Themes/CallTheme.xaml b/CallApp.Tizen/Call/Themes/CallTheme.xaml
deleted file mode 100644
index 1e58f41..0000000
--- a/CallApp.Tizen/Call/Themes/CallTheme.xaml
+++ /dev/null
@@ -1,15 +0,0 @@
-<?xml version="1.0" encoding="utf-8" ?>
-<ResourceDictionary xmlns="http://xamarin.com/schemas/2014/forms"
- xmlns:x="http://schemas.microsoft.com/winfx/2009/xaml"
- x:Class="CallApp.Tizen.Call.Themes.CallTheme">
-
- <Color x:Key="CallBGColor">#FFF7F7F7</Color>
- <Color x:Key="CallDefaultTextColor">#FFFAFAFA</Color>
-
- <Color x:Key="CallButtonCircleAcceptNormalColor">#FF59B03A</Color>
- <Color x:Key="CallButtonCircleAcceptPressColor">#FF268035</Color>
-
- <Color x:Key="CallButtonCircleRejectBGColor">#4DE02222</Color>
- <Color x:Key="CallButtonCircleRejectNormalColor">#FFD63131</Color>
- <Color x:Key="CallButtonCircleRejectPressColor">#FFA32626</Color>
-</ResourceDictionary> \ No newline at end of file
diff --git a/CallApp.Tizen/Call/Pages/ConferenceCallManagePage.xaml b/CallApp.Tizen/Call/View/ConferenceCallManagePage.xaml
index 474c312..0e92884 100644
--- a/CallApp.Tizen/Call/Pages/ConferenceCallManagePage.xaml
+++ b/CallApp.Tizen/Call/View/ConferenceCallManagePage.xaml
@@ -1,21 +1,20 @@
<?xml version="1.0" encoding="utf-8" ?>
<ContentPage xmlns="http://xamarin.com/schemas/2014/forms"
xmlns:x="http://schemas.microsoft.com/winfx/2009/xaml"
- x:Class="CallApp.Tizen.Call.Pages.ConferenceCallManagePage"
- xmlns:callControls="clr-namespace:CallApp.Tizen.Call.Controls"
- xmlns:callThemes="clr-namespace:CallApp.Tizen.Call.Themes"
- xmlns:commonControls="clr-namespace:CallApp.Tizen.Common.Controls"
- xmlns:loc="clr-namespace:CallApp.Tizen.loc">
+ x:Class="CallApp.Tizen.Call.View.ConferenceCallManagePage"
+ xmlns:CallControls="clr-namespace:CallApp.Tizen.Call.View.Controls"
+ xmlns:Localization="clr-namespace:CallApp.Tizen.Localization"
+ xmlns:TizenUtilityControls="clr-namespace:Tizen.Utility.Controls">
<ContentPage.Resources>
- <ResourceDictionary MergedWith="callThemes:CallTheme">
+ <ResourceDictionary>
<Color x:Key="BackPanelBGColor">#FFFFFFFF</Color>
<Color x:Key="BackButtonColor">#FF5868B0</Color>
<Color x:Key="CallStatusBGColor">#FF3DB9CC</Color>
</ResourceDictionary>
</ContentPage.Resources>
- <commonControls:CustomGrid>
+ <TizenUtilityControls:CustomGrid>
<Grid.RowDefinitions>
<RowDefinition Height="54" />
<RowDefinition Height="*" />
@@ -23,15 +22,15 @@
</Grid.RowDefinitions>
<ContentView Grid.Row="0" BackgroundColor="{StaticResource CallStatusBGColor}">
- <Label Margin="32,0,0,0" HorizontalOptions="Start" VerticalOptions="Center" TextColor="{StaticResource CallDefaultTextColor}"
+ <Label Margin="32,0,0,0" HorizontalOptions="Start" VerticalOptions="Center" TextColor="{StaticResource DefaultTextColor}"
FontSize="27" Text="00:00" />
</ContentView>
- <callControls:ConferenceCallManageList Grid.Row="1" />
+ <CallControls:ConferenceCallManageList Grid.Row="1" />
<ContentView Grid.Row="2" BackgroundColor="{StaticResource BackPanelBGColor}">
<Button WidthRequest="524" HeightRequest="104" HorizontalOptions="Center" VerticalOptions="Center"
- BackgroundColor="{StaticResource BackButtonColor}" Text="{x:Static loc:loc.ReturnToCallScreen}" Command="{Binding BackCommand}" />
+ BackgroundColor="{StaticResource BackButtonColor}" Text="{x:Static Localization:Localization.ReturnToCallScreen}" Command="{Binding BackCommand}" />
</ContentView>
- </commonControls:CustomGrid>
+ </TizenUtilityControls:CustomGrid>
</ContentPage> \ No newline at end of file
diff --git a/CallApp.Tizen/Call/Pages/ConferenceCallManagePage.xaml.cs b/CallApp.Tizen/Call/View/ConferenceCallManagePage.xaml.cs
index fbede2a..230ac02 100644
--- a/CallApp.Tizen/Call/Pages/ConferenceCallManagePage.xaml.cs
+++ b/CallApp.Tizen/Call/View/ConferenceCallManagePage.xaml.cs
@@ -16,7 +16,7 @@
using Xamarin.Forms;
-namespace CallApp.Tizen.Call.Pages
+namespace CallApp.Tizen.Call.View
{
/// <summary>
/// Partial class of ConferenceCallManagePage.xaml
diff --git a/CallApp.Tizen/Call/Controls/AnimatedCircleButton.xaml b/CallApp.Tizen/Call/View/Controls/AnimatedCircleButton.xaml
index ca4cd12..c79be16 100644
--- a/CallApp.Tizen/Call/Controls/AnimatedCircleButton.xaml
+++ b/CallApp.Tizen/Call/View/Controls/AnimatedCircleButton.xaml
@@ -1,20 +1,20 @@
<?xml version="1.0" encoding="utf-8" ?>
<ContentView xmlns="http://xamarin.com/schemas/2014/forms"
xmlns:x="http://schemas.microsoft.com/winfx/2009/xaml"
- x:Class="CallApp.Tizen.Call.Controls.AnimatedCircleButton"
+ x:Class="CallApp.Tizen.Call.View.Controls.AnimatedCircleButton"
x:Name="This"
- xmlns:commonControls="clr-namespace:CallApp.Tizen.Common.Controls"
- xmlns:extension="clr-namespace:Tizen.Xamarin.Forms.Extension;assembly=Tizen.Xamarin.Forms.Extension">
+ xmlns:Extension="clr-namespace:Tizen.Xamarin.Forms.Extension;assembly=Tizen.Xamarin.Forms.Extension"
+ xmlns:TizenUtilityControls="clr-namespace:Tizen.Utility.Controls">
<ContentView.GestureRecognizers>
- <extension:LongTapGestureRecognizer TapStarted="OnTapStart" TapCanceled="OnTapEnd" TapCompleted="OnTapEnd" />
+ <Extension:LongTapGestureRecognizer TapStarted="OnTapStart" TapCanceled="OnTapEnd" TapCompleted="OnTapEnd" />
</ContentView.GestureRecognizers>
- <commonControls:GesturesContainer x:Name="xGesturesContainer">
- <commonControls:CustomGrid>
- <commonControls:CustomImage x:Name="xImage" HorizontalOptions="Center" VerticalOptions="Center"
- WidthRequest="{Binding Radius, Source={x:Reference This}}" HeightRequest="{Binding Radius, Source={x:Reference This}}"
- BlendingColor="{Binding AnimationColor, Source={x:Reference This}}" Source="call_button_bg_accept_reject.png" />
+ <TizenUtilityControls:GesturesContainer x:Name="xGesturesContainer">
+ <TizenUtilityControls:CustomGrid>
+ <TizenUtilityControls:CustomImage x:Name="xImage" HorizontalOptions="Center" VerticalOptions="Center"
+ WidthRequest="{Binding Radius, Source={x:Reference This}}" HeightRequest="{Binding Radius, Source={x:Reference This}}"
+ BlendingColor="{Binding AnimationColor, Source={x:Reference This}}" Source="call_button_bg_accept_reject.png" />
<Button x:Name="xButton" HorizontalOptions="Center" VerticalOptions="Center"
WidthRequest="{Binding Radius, Source={x:Reference This}}" HeightRequest="{Binding Radius, Source={x:Reference This}}"
@@ -25,6 +25,6 @@
</DataTrigger>
</Button.Triggers>
</Button>
- </commonControls:CustomGrid>
- </commonControls:GesturesContainer>
+ </TizenUtilityControls:CustomGrid>
+ </TizenUtilityControls:GesturesContainer>
</ContentView> \ No newline at end of file
diff --git a/CallApp.Tizen/Call/Controls/AnimatedCircleButton.xaml.cs b/CallApp.Tizen/Call/View/Controls/AnimatedCircleButton.xaml.cs
index 8b17049..0bbbb6e 100644
--- a/CallApp.Tizen/Call/Controls/AnimatedCircleButton.xaml.cs
+++ b/CallApp.Tizen/Call/View/Controls/AnimatedCircleButton.xaml.cs
@@ -18,7 +18,7 @@ using System;
using Xamarin.Forms;
using Xamarin.Forms.PlatformConfiguration.TizenSpecific;
-namespace CallApp.Tizen.Call.Controls
+namespace CallApp.Tizen.Call.View.Controls
{
/// <summary>
/// Partial class of AnimatedCircleButton.xaml
diff --git a/CallApp.Tizen/Call/Controls/CallHandlingPanel.xaml b/CallApp.Tizen/Call/View/Controls/CallHandlingPanel.xaml
index 807d821..47ad870 100644
--- a/CallApp.Tizen/Call/Controls/CallHandlingPanel.xaml
+++ b/CallApp.Tizen/Call/View/Controls/CallHandlingPanel.xaml
@@ -1,14 +1,13 @@
<?xml version="1.0" encoding="UTF-8"?>
<ContentView xmlns="http://xamarin.com/schemas/2014/forms"
xmlns:x="http://schemas.microsoft.com/winfx/2009/xaml"
- x:Class="CallApp.Tizen.Call.Controls.CallHandlingPanel"
- xmlns:callControls="clr-namespace:CallApp.Tizen.Call.Controls"
- xmlns:callThemes="clr-namespace:CallApp.Tizen.Call.Themes"
- xmlns:commonControls="clr-namespace:CallApp.Tizen.Common.Controls"
- xmlns:loc="clr-namespace:CallApp.Tizen.loc">
+ x:Class="CallApp.Tizen.Call.View.Controls.CallHandlingPanel"
+ xmlns:CallControls="clr-namespace:CallApp.Tizen.Call.View.Controls"
+ xmlns:Localization="clr-namespace:CallApp.Tizen.Localization"
+ xmlns:TizenUtilityControls="clr-namespace:Tizen.Utility.Controls">
<ContentView.Resources>
- <ResourceDictionary MergedWith="callThemes:CallTheme">
+ <ResourceDictionary>
<Color x:Key="FlatControlBorderColor">#FFD9D9D9</Color>
<Color x:Key="FlatControlCheckOffColor">#4C666666</Color>
<Color x:Key="FlatControlCheckOnColor">#FF2EB4C8</Color>
@@ -17,7 +16,7 @@
<Color x:Key="FlatControlNormalColor">#FFFAFAFA</Color>
<Color x:Key="FlatControlTextNormalColor">#FF808080</Color>
- <Style TargetType="callControls:FlatButton">
+ <Style TargetType="CallControls:FlatButton">
<Setter Property="HeightRequest" Value="188" />
<Setter Property="ImageColor" Value="{StaticResource FlatControlImageNormalColor}" />
<Setter Property="TextColor" Value="{StaticResource FlatControlTextNormalColor}" />
@@ -25,7 +24,7 @@
<Setter Property="NormalColor" Value="{StaticResource FlatControlNormalColor}" />
</Style>
- <Style TargetType="callControls:FlatCheckbox">
+ <Style TargetType="CallControls:FlatCheckbox">
<Setter Property="HeightRequest" Value="188" />
<Setter Property="ImageColor" Value="{StaticResource FlatControlImageNormalColor}" />
<Setter Property="TextColor" Value="{StaticResource FlatControlTextNormalColor}" />
@@ -42,7 +41,7 @@
</ResourceDictionary>
</ContentView.Resources>
- <commonControls:CustomGrid>
+ <TizenUtilityControls:CustomGrid>
<Grid.ColumnDefinitions>
<ColumnDefinition Width="*" />
</Grid.ColumnDefinitions>
@@ -52,7 +51,7 @@
<RowDefinition Height="152" />
</Grid.RowDefinitions>
- <commonControls:CustomGrid Grid.Column="0" Grid.Row="0">
+ <TizenUtilityControls:CustomGrid Grid.Column="0" Grid.Row="0">
<Grid.ColumnDefinitions>
<ColumnDefinition Width="*" />
<ColumnDefinition Width="*" />
@@ -65,30 +64,30 @@
</Grid.RowDefinitions>
<Frame Grid.Column="0" Grid.Row="0" Padding="0,0,2,2">
- <callControls:FlatCheckbox Image="call_btn_volume.png" Text="{x:Static loc:loc.Speaker}" />
+ <CallControls:FlatCheckbox Image="call_btn_volume.png" Text="{x:Static Localization:Localization.Speaker}" />
</Frame>
<Frame Grid.Column="1" Grid.Row="0" Padding="0,0,2,2">
- <callControls:FlatButton Image="call_btn_keypad.png" Text="{x:Static loc:loc.Keypad}" />
+ <CallControls:FlatButton Image="call_btn_keypad.png" Text="{x:Static Localization:Localization.Keypad}" />
</Frame>
<Frame Grid.Column="2" Grid.Row="0" Padding="0,0,0,2">
- <callControls:FlatCheckbox Image="call_btn_bluetooth.png" Text="{x:Static loc:loc.Bluetooth}" />
+ <CallControls:FlatCheckbox Image="call_btn_bluetooth.png" Text="{x:Static Localization:Localization.Bluetooth}" />
</Frame>
<Frame Grid.Column="0" Grid.Row="1" Padding="0,0,2,2">
- <callControls:FlatButton Image="call_btn_addcall.png" Text="{x:Static loc:loc.AddCall}" />
+ <CallControls:FlatButton Image="call_btn_addcall.png" Text="{x:Static Localization:Localization.AddCall}" />
</Frame>
<Frame Grid.Column="1" Grid.Row="1" Padding="0,0,2,2">
- <callControls:FlatCheckbox Image="call_btn_mute.png" Text="{x:Static loc:loc.Mute}" />
+ <CallControls:FlatCheckbox Image="call_btn_mute.png" Text="{x:Static Localization:Localization.Mute}" />
</Frame>
<Frame Grid.Column="2" Grid.Row="1" Padding="0,0,0,2">
- <callControls:FlatButton Image="call_btn_contacts.png" Text="{x:Static loc:loc.Contacts}" />
+ <CallControls:FlatButton Image="call_btn_contacts.png" Text="{x:Static Localization:Localization.Contacts}" />
</Frame>
- </commonControls:CustomGrid>
+ </TizenUtilityControls:CustomGrid>
- <commonControls:CustomGrid Grid.Column="0" Grid.Row="1" BackgroundColor="{StaticResource CallBGColor}">
- <callControls:AnimatedCircleButton HorizontalOptions="Center" VerticalOptions="Center" Radius="100"
- AnimationColor="{StaticResource CallButtonCircleRejectBGColor}" NormalColor="{StaticResource CallButtonCircleRejectNormalColor}"
- PressColor="{StaticResource CallButtonCircleRejectPressColor}" Image="call_btn_ic_reject.png" />
- </commonControls:CustomGrid>
- </commonControls:CustomGrid>
+ <TizenUtilityControls:CustomGrid Grid.Column="0" Grid.Row="1" BackgroundColor="{StaticResource BGColor}">
+ <CallControls:AnimatedCircleButton HorizontalOptions="Center" VerticalOptions="Center" Radius="100"
+ AnimationColor="{StaticResource CircleButtonRejectBGColor}" NormalColor="{StaticResource CircleButtonRejectNormalColor}"
+ PressColor="{StaticResource CircleButtonRejectPressColor}" Image="call_btn_ic_reject.png" />
+ </TizenUtilityControls:CustomGrid>
+ </TizenUtilityControls:CustomGrid>
</ContentView> \ No newline at end of file
diff --git a/CallApp.Tizen/Call/Controls/CallHandlingPanel.xaml.cs b/CallApp.Tizen/Call/View/Controls/CallHandlingPanel.xaml.cs
index d8b4969..2d9f680 100644
--- a/CallApp.Tizen/Call/Controls/CallHandlingPanel.xaml.cs
+++ b/CallApp.Tizen/Call/View/Controls/CallHandlingPanel.xaml.cs
@@ -16,7 +16,7 @@
using Xamarin.Forms;
-namespace CallApp.Tizen.Call.Controls
+namespace CallApp.Tizen.Call.View.Controls
{
/// <summary>
/// Partial class of CallHandlingPanel.xaml
diff --git a/CallApp.Tizen/Call/Controls/ConferenceCallManageList.xaml b/CallApp.Tizen/Call/View/Controls/ConferenceCallManageList.xaml
index 1850a00..37dd468 100644
--- a/CallApp.Tizen/Call/Controls/ConferenceCallManageList.xaml
+++ b/CallApp.Tizen/Call/View/Controls/ConferenceCallManageList.xaml
@@ -1,15 +1,13 @@
<?xml version="1.0" encoding="UTF-8"?>
<ContentView xmlns="http://xamarin.com/schemas/2014/forms"
xmlns:x="http://schemas.microsoft.com/winfx/2009/xaml"
- x:Class="CallApp.Tizen.Call.Controls.ConferenceCallManageList"
+ x:Class="CallApp.Tizen.Call.View.Controls.ConferenceCallManageList"
x:Name="This"
- xmlns:callControls="clr-namespace:CallApp.Tizen.Call.Controls"
- xmlns:callThemes="clr-namespace:CallApp.Tizen.Call.Themes"
- xmlns:commonControls="clr-namespace:CallApp.Tizen.Common.Controls"
- xmlns:commonInput="clr-namespace:CallApp.Tizen.Common.Input">
+ xmlns:CallControls="clr-namespace:CallApp.Tizen.Call.View.Controls"
+ xmlns:TizenUtilityControls="clr-namespace:Tizen.Utility.Controls">
<ContentView.Resources>
- <ResourceDictionary MergedWith="callThemes:CallTheme">
+ <ResourceDictionary>
<Color x:Key="ContactNameTextColor">#FF000000</Color>
<Color x:Key="SplitButtonNormalColor">#FF3DB9CC</Color>
<Color x:Key="SplitButtonPressColor">#FF2F919F</Color>
@@ -20,8 +18,8 @@
<ListView.ItemTemplate>
<DataTemplate>
<ViewCell>
- <StackLayout HeightRequest="144" Orientation="Horizontal" BackgroundColor="{StaticResource CallBGColor}">
- <callControls:AnimatedCircleButton Margin="32,0,0,0" Radius="98"
+ <StackLayout HeightRequest="144" Orientation="Horizontal" BackgroundColor="{StaticResource BGColor}">
+ <CallControls:AnimatedCircleButton Margin="32,0,0,0" Radius="98"
NormalColor="{StaticResource SplitButtonNormalColor}" PressColor="{StaticResource SplitButtonPressColor}"
Image="call_btn_ic_split.png" />
@@ -30,8 +28,8 @@
<Label Margin="32,0,0,0" WidthRequest="268" HorizontalOptions="Start" VerticalOptions="Center"
TextColor="{StaticResource ContactNameTextColor}" FontSize="21" Text="{Binding ContactName}" />
- <callControls:AnimatedCircleButton Margin="32,0,0,0" Radius="98"
- NormalColor="{StaticResource CallButtonCircleRejectNormalColor}" PressColor="{StaticResource CallButtonCircleRejectPressColor}"
+ <CallControls:AnimatedCircleButton Margin="32,0,0,0" Radius="98"
+ NormalColor="{StaticResource CircleButtonRejectNormalColor}" PressColor="{StaticResource CircleButtonRejectPressColor}"
Image="call_btn_ic_reject.png" />
</StackLayout>
</ViewCell>
diff --git a/CallApp.Tizen/Call/Controls/ConferenceCallManageList.xaml.cs b/CallApp.Tizen/Call/View/Controls/ConferenceCallManageList.xaml.cs
index 5f1a629..08685b5 100644
--- a/CallApp.Tizen/Call/Controls/ConferenceCallManageList.xaml.cs
+++ b/CallApp.Tizen/Call/View/Controls/ConferenceCallManageList.xaml.cs
@@ -16,7 +16,7 @@
using Xamarin.Forms;
-namespace CallApp.Tizen.Call.Controls
+namespace CallApp.Tizen.Call.View.Controls
{
/// <summary>
/// Partial class of ConferenceCallManageList.xaml
diff --git a/CallApp.Tizen/Call/Controls/ContactInfoPanel.xaml b/CallApp.Tizen/Call/View/Controls/ContactInfoPanel.xaml
index d308a52..4ba4365 100644
--- a/CallApp.Tizen/Call/Controls/ContactInfoPanel.xaml
+++ b/CallApp.Tizen/Call/View/Controls/ContactInfoPanel.xaml
@@ -1,16 +1,15 @@
<?xml version="1.0" encoding="UTF-8"?>
<ContentView xmlns="http://xamarin.com/schemas/2014/forms"
xmlns:x="http://schemas.microsoft.com/winfx/2009/xaml"
- x:Class="CallApp.Tizen.Call.Controls.ContactInfoPanel"
+ x:Class="CallApp.Tizen.Call.View.Controls.ContactInfoPanel"
x:Name="This"
- xmlns:callControls="clr-namespace:CallApp.Tizen.Call.Controls"
- xmlns:callThemes="clr-namespace:CallApp.Tizen.Call.Themes"
- xmlns:commonControls="clr-namespace:CallApp.Tizen.Common.Controls">
+ xmlns:CallControls="clr-namespace:CallApp.Tizen.Call.View.Controls"
+ xmlns:TizenUtilityControls="clr-namespace:Tizen.Utility.Controls">
<ContentView.Resources>
- <ResourceDictionary MergedWith="callThemes:CallTheme">
+ <ResourceDictionary>
<ControlTemplate x:Key="ActivePanel">
- <commonControls:CustomGrid HeightRequest="172">
+ <TizenUtilityControls:CustomGrid HeightRequest="172">
<Grid.ColumnDefinitions>
<ColumnDefinition Width="160" />
<ColumnDefinition Width="*" />
@@ -26,21 +25,21 @@
</RelativeLayout>
<StackLayout Grid.Column="1" VerticalOptions="Center">
- <Label HeightRequest="43" HorizontalOptions="Start" VerticalOptions="Center" TextColor="{StaticResource CallDefaultTextColor}"
+ <Label HeightRequest="43" HorizontalOptions="Start" VerticalOptions="Center" TextColor="{StaticResource DefaultTextColor}"
FontSize="21" Text="{TemplateBinding StatusText}" />
- <Label HeightRequest="53" HorizontalOptions="Start" VerticalOptions="Center" TextColor="{StaticResource CallDefaultTextColor}"
+ <Label HeightRequest="53" HorizontalOptions="Start" VerticalOptions="Center" TextColor="{StaticResource DefaultTextColor}"
FontSize="26" Text="{TemplateBinding PrimaryText}" />
<Label HeightRequest="43" HorizontalOptions="Start" VerticalOptions="Center"
- TextColor="{StaticResource CallDefaultTextColor}" FontSize="21" Text="{TemplateBinding SecondaryText}"
+ TextColor="{StaticResource DefaultTextColor}" FontSize="21" Text="{TemplateBinding SecondaryText}"
IsVisible="False" />
</StackLayout>
- </commonControls:CustomGrid>
+ </TizenUtilityControls:CustomGrid>
</ControlTemplate>
<ControlTemplate x:Key="ConferencePanel">
- <commonControls:CustomGrid>
+ <TizenUtilityControls:CustomGrid>
<Grid.ColumnDefinitions>
<ColumnDefinition Width="104" />
<ColumnDefinition Width="*" />
@@ -52,7 +51,7 @@
<RowDefinition Height="Auto" />
</Grid.RowDefinitions>
- <commonControls:CustomGrid Grid.Column="1" Grid.Row="0">
+ <TizenUtilityControls:CustomGrid Grid.Column="1" Grid.Row="0">
<Grid.RowDefinitions>
<RowDefinition Height="24" />
<RowDefinition Height="54" />
@@ -60,13 +59,13 @@
<RowDefinition Height="348" />
</Grid.RowDefinitions>
- <Label Grid.Row="1" HorizontalOptions="Start" VerticalOptions="Center" TextColor="{StaticResource CallDefaultTextColor}"
+ <Label Grid.Row="1" HorizontalOptions="Start" VerticalOptions="Center" TextColor="{StaticResource DefaultTextColor}"
FontSize="27" Text="{TemplateBinding StatusText}" />
<Image Grid.Row="3" HorizontalOptions="Center" VerticalOptions="Center" Source="{TemplateBinding Image}" />
- </commonControls:CustomGrid>
+ </TizenUtilityControls:CustomGrid>
- <commonControls:CustomGrid Grid.Column="1" Grid.Row="1">
+ <TizenUtilityControls:CustomGrid Grid.Column="1" Grid.Row="1">
<Grid.RowDefinitions>
<RowDefinition Height="42" />
<RowDefinition Height="86" />
@@ -75,20 +74,20 @@
<RowDefinition Height="63" />
</Grid.RowDefinitions>
- <Label Grid.Row="1" HorizontalOptions="Center" VerticalOptions="Center" TextColor="{StaticResource CallDefaultTextColor}"
+ <Label Grid.Row="1" HorizontalOptions="Center" VerticalOptions="Center" TextColor="{StaticResource DefaultTextColor}"
FontSize="47" Text="{TemplateBinding PrimaryText}" />
- <Label Grid.Row="3" HorizontalOptions="Center" VerticalOptions="Center" TextColor="{StaticResource CallDefaultTextColor}"
+ <Label Grid.Row="3" HorizontalOptions="Center" VerticalOptions="Center" TextColor="{StaticResource DefaultTextColor}"
FontSize="27" Text="{TemplateBinding SecondaryText}" />
- </commonControls:CustomGrid>
+ </TizenUtilityControls:CustomGrid>
- <callControls:FlatButton Grid.Column="2" Grid.Row="1" WidthRequest="50" HeightRequest="50" Margin="0,32,-22,0"
+ <CallControls:FlatButton Grid.Column="2" Grid.Row="1" WidthRequest="50" HeightRequest="50" Margin="0,32,-22,0"
HorizontalOptions="Center" VerticalOptions="Center" Image="call_multi_ic_arrow.png" />
- </commonControls:CustomGrid>
+ </TizenUtilityControls:CustomGrid>
</ControlTemplate>
<ControlTemplate x:Key="EmergencyPanel">
- <commonControls:CustomGrid>
+ <TizenUtilityControls:CustomGrid>
<Grid.ColumnDefinitions>
<ColumnDefinition Width="32" />
<ColumnDefinition Width="*" />
@@ -105,18 +104,18 @@
<RowDefinition Height="96" />
</Grid.RowDefinitions>
- <Label Grid.Column="1" Grid.Row="1" HorizontalOptions="Start" VerticalOptions="Center" TextColor="{StaticResource CallDefaultTextColor}"
+ <Label Grid.Column="1" Grid.Row="1" HorizontalOptions="Start" VerticalOptions="Center" TextColor="{StaticResource DefaultTextColor}"
FontSize="27" Text="{TemplateBinding StatusText}" />
<Image Grid.Column="1" Grid.Row="3" HorizontalOptions="Center" VerticalOptions="Center" Source="Call ID/348x348/call_photo_id_emergency.png" />
- <Label Grid.Column="1" Grid.Row="5" HorizontalOptions="Center" VerticalOptions="Center" TextColor="{StaticResource CallDefaultTextColor}"
+ <Label Grid.Column="1" Grid.Row="5" HorizontalOptions="Center" VerticalOptions="Center" TextColor="{StaticResource DefaultTextColor}"
FontSize="47" Text="{TemplateBinding PrimaryText}" />
- </commonControls:CustomGrid>
+ </TizenUtilityControls:CustomGrid>
</ControlTemplate>
<ControlTemplate x:Key="SinglePanel">
- <commonControls:CustomGrid>
+ <TizenUtilityControls:CustomGrid>
<Grid.ColumnDefinitions>
<ColumnDefinition Width="32" />
<ColumnDefinition Width="*" />
@@ -135,21 +134,21 @@
<RowDefinition Height="63" />
</Grid.RowDefinitions>
- <Label Grid.Column="1" Grid.Row="1" HorizontalOptions="Start" VerticalOptions="Center" TextColor="{StaticResource CallDefaultTextColor}"
+ <Label Grid.Column="1" Grid.Row="1" HorizontalOptions="Start" VerticalOptions="Center" TextColor="{StaticResource DefaultTextColor}"
FontSize="27" Text="{TemplateBinding StatusText}" />
<Image Grid.Column="1" Grid.Row="3" HorizontalOptions="Center" VerticalOptions="Center" Source="{TemplateBinding Image}" />
- <Label Grid.Column="1" Grid.Row="5" HorizontalOptions="Center" VerticalOptions="Center" TextColor="{StaticResource CallDefaultTextColor}"
+ <Label Grid.Column="1" Grid.Row="5" HorizontalOptions="Center" VerticalOptions="Center" TextColor="{StaticResource DefaultTextColor}"
FontSize="47" Text="{TemplateBinding PrimaryText}" />
- <Label Grid.Column="1" Grid.Row="7" HorizontalOptions="Center" VerticalOptions="Center" TextColor="{StaticResource CallDefaultTextColor}"
+ <Label Grid.Column="1" Grid.Row="7" HorizontalOptions="Center" VerticalOptions="Center" TextColor="{StaticResource DefaultTextColor}"
FontSize="27" Text="{TemplateBinding SecondaryText}" />
- </commonControls:CustomGrid>
+ </TizenUtilityControls:CustomGrid>
</ControlTemplate>
<ControlTemplate x:Key="TopPanel">
- <commonControls:CustomGrid>
+ <TizenUtilityControls:CustomGrid>
<Grid.ColumnDefinitions>
<ColumnDefinition Width="232" />
<ColumnDefinition Width="*" />
@@ -163,12 +162,12 @@
</Grid.RowDefinitions>
<Label Grid.Column="0" Grid.Row="1" Margin="32,0,0,0" HorizontalOptions="Start" VerticalOptions="Center"
- TextColor="{StaticResource CallDefaultTextColor}" FontSize="27" Text="{TemplateBinding StatusText}" />
+ TextColor="{StaticResource DefaultTextColor}" FontSize="27" Text="{TemplateBinding StatusText}" />
<Image Grid.Column="0" Grid.Row="2" Margin="32,0,32,0" WidthRequest="168" HeightRequest="168"
HorizontalOptions="Center" VerticalOptions="Center" Source="{TemplateBinding Image}" />
- <commonControls:CustomGrid Grid.Column="1" Grid.Row="2">
+ <TizenUtilityControls:CustomGrid Grid.Column="1" Grid.Row="2">
<Grid.RowDefinitions>
<RowDefinition Height="50" />
<RowDefinition Height="76" />
@@ -176,16 +175,16 @@
<RowDefinition Height="46" />
</Grid.RowDefinitions>
- <Label Grid.Row="1" HorizontalOptions="Start" VerticalOptions="Center" TextColor="{StaticResource CallDefaultTextColor}"
+ <Label Grid.Row="1" HorizontalOptions="Start" VerticalOptions="Center" TextColor="{StaticResource DefaultTextColor}"
FontSize="38" Text="{TemplateBinding PrimaryText}" />
- <Label Grid.Row="3" HorizontalOptions="Start" VerticalOptions="Center" TextColor="{StaticResource CallDefaultTextColor}"
+ <Label Grid.Row="3" HorizontalOptions="Start" VerticalOptions="Center" TextColor="{StaticResource DefaultTextColor}"
FontSize="23" Text="{TemplateBinding SecondaryText}" />
- </commonControls:CustomGrid>
+ </TizenUtilityControls:CustomGrid>
- <callControls:FlatButton Grid.Column="2" Grid.Row="2" WidthRequest="80" HeightRequest="80"
+ <CallControls:FlatButton Grid.Column="2" Grid.Row="2" WidthRequest="80" HeightRequest="80"
Margin="32,74,0,0" Image="call_btn_addcall.png" IsVisible="False" />
- </commonControls:CustomGrid>
+ </TizenUtilityControls:CustomGrid>
</ControlTemplate>
</ResourceDictionary>
</ContentView.Resources>
diff --git a/CallApp.Tizen/Call/Controls/ContactInfoPanel.xaml.cs b/CallApp.Tizen/Call/View/Controls/ContactInfoPanel.xaml.cs
index 29cd54f..6b50540 100644
--- a/CallApp.Tizen/Call/Controls/ContactInfoPanel.xaml.cs
+++ b/CallApp.Tizen/Call/View/Controls/ContactInfoPanel.xaml.cs
@@ -16,7 +16,7 @@
using Xamarin.Forms;
-namespace CallApp.Tizen.Call.Controls
+namespace CallApp.Tizen.Call.View.Controls
{
/// <summary>
/// Partial class of ContactInfoPanel.xaml
diff --git a/CallApp.Tizen/Call/Controls/FlatButton.xaml b/CallApp.Tizen/Call/View/Controls/FlatButton.xaml
index 868e684..4dfc20f 100644
--- a/CallApp.Tizen/Call/Controls/FlatButton.xaml
+++ b/CallApp.Tizen/Call/View/Controls/FlatButton.xaml
@@ -1,23 +1,23 @@
<?xml version="1.0" encoding="UTF-8"?>
<ContentView xmlns="http://xamarin.com/schemas/2014/forms"
xmlns:x="http://schemas.microsoft.com/winfx/2009/xaml"
- x:Class="CallApp.Tizen.Call.Controls.FlatButton"
- xmlns:commonControls="clr-namespace:CallApp.Tizen.Common.Controls"
- xmlns:commonConverters="clr-namespace:CallApp.Tizen.Common.Converters"
- xmlns:commonInput="clr-namespace:CallApp.Tizen.Common.Input"
+ x:Class="CallApp.Tizen.Call.View.Controls.FlatButton"
+ xmlns:TizenUtilityControls="clr-namespace:Tizen.Utility.Controls"
+ xmlns:TizenUtilityConverters="clr-namespace:Tizen.Utility.Converters"
+ xmlns:TizenUtilityInput="clr-namespace:Tizen.Utility.Input"
ControlTemplate="{StaticResource FlatButtonControlTemplate}">
<ContentView.Resources>
<ResourceDictionary>
<Color x:Key="PressColor">#4C000000</Color>
- <commonConverters:IsNullConverter x:Key="IsNull" />
- <commonConverters:IsStringEmptyConverter x:Key="IsStringEmpty" />
+ <TizenUtilityConverters:IsNullConverter x:Key="IsNull" />
+ <TizenUtilityConverters:IsStringEmptyConverter x:Key="IsStringEmpty" />
<ControlTemplate x:Key="FlatButtonControlTemplate">
<ContentView BackgroundColor="{TemplateBinding NormalColor}">
<StackLayout HorizontalOptions="FillAndExpand" VerticalOptions="FillAndExpand">
<StackLayout.Triggers>
- <Trigger TargetType="StackLayout" Property="commonInput:GesturesInput.IsTap" Value="True">
+ <Trigger TargetType="StackLayout" Property="TizenUtilityInput:GesturesInput.IsTap" Value="True">
<!-- Should be -->
<!-- <Setter Property="BackgroundColor" Value="{TemplateBinding PressColor}" /> -->
<!-- But -->
@@ -26,18 +26,18 @@
</Trigger>
</StackLayout.Triggers>
- <commonControls:CustomImage HeightRequest="62" Margin="0,37,0,0" Source="{TemplateBinding Image}"
- BlendingColor="{TemplateBinding ImageColor}">
- <commonControls:CustomImage.Triggers>
- <DataTrigger TargetType="commonControls:CustomImage" Binding="{TemplateBinding Image, Converter={StaticResource IsNull}}" Value="True">
+ <TizenUtilityControls:CustomImage HeightRequest="62" Margin="0,37,0,0" Source="{TemplateBinding Image}"
+ BlendingColor="{TemplateBinding ImageColor}">
+ <TizenUtilityControls:CustomImage.Triggers>
+ <DataTrigger TargetType="TizenUtilityControls:CustomImage" Binding="{TemplateBinding Image, Converter={StaticResource IsNull}}" Value="True">
<Setter Property="IsVisible" Value="False" />
</DataTrigger>
- <DataTrigger TargetType="commonControls:CustomImage" Binding="{TemplateBinding IsEnabled}" Value="False">
+ <DataTrigger TargetType="TizenUtilityControls:CustomImage" Binding="{TemplateBinding IsEnabled}" Value="False">
<Setter Property="BlendingColor" Value="{TemplateBinding DimColor}" />
</DataTrigger>
- </commonControls:CustomImage.Triggers>
- </commonControls:CustomImage>
+ </TizenUtilityControls:CustomImage.Triggers>
+ </TizenUtilityControls:CustomImage>
<Label HeightRequest="37" Margin="0,4,0,0" HorizontalOptions="Center"
FontSize="19" Text="{TemplateBinding Text}" TextColor="{TemplateBinding TextColor}">
diff --git a/CallApp.Tizen/Call/Controls/FlatButton.xaml.cs b/CallApp.Tizen/Call/View/Controls/FlatButton.xaml.cs
index 74d2a7e..57da453 100644
--- a/CallApp.Tizen/Call/Controls/FlatButton.xaml.cs
+++ b/CallApp.Tizen/Call/View/Controls/FlatButton.xaml.cs
@@ -16,7 +16,7 @@
using Xamarin.Forms;
-namespace CallApp.Tizen.Call.Controls
+namespace CallApp.Tizen.Call.View.Controls
{
/// <summary>
/// Partial class of FlatButton.xaml
diff --git a/CallApp.Tizen/Call/Controls/FlatCheckbox.xaml b/CallApp.Tizen/Call/View/Controls/FlatCheckbox.xaml
index fb0713d..f6bf0d7 100644
--- a/CallApp.Tizen/Call/Controls/FlatCheckbox.xaml
+++ b/CallApp.Tizen/Call/View/Controls/FlatCheckbox.xaml
@@ -1,21 +1,21 @@
<?xml version="1.0" encoding="UTF-8"?>
-<callControls:FlatButton xmlns="http://xamarin.com/schemas/2014/forms"
+<CallControls:FlatButton xmlns="http://xamarin.com/schemas/2014/forms"
xmlns:x="http://schemas.microsoft.com/winfx/2009/xaml"
- x:Class="CallApp.Tizen.Call.Controls.FlatCheckbox"
+ x:Class="CallApp.Tizen.Call.View.Controls.FlatCheckbox"
x:Name="This"
- xmlns:callControls="clr-namespace:CallApp.Tizen.Call.Controls"
- xmlns:extension="clr-namespace:Tizen.Xamarin.Forms.Extension;assembly=Tizen.Xamarin.Forms.Extension">
+ xmlns:CallControls="clr-namespace:CallApp.Tizen.Call.View.Controls"
+ xmlns:Extension="clr-namespace:Tizen.Xamarin.Forms.Extension;assembly=Tizen.Xamarin.Forms.Extension">
- <callControls:FlatButton.GestureRecognizers>
- <extension:LongTapGestureRecognizer TapStarted="OnTapStart" />
- </callControls:FlatButton.GestureRecognizers>
+ <CallControls:FlatButton.GestureRecognizers>
+ <Extension:LongTapGestureRecognizer TapStarted="OnTapStart" />
+ </CallControls:FlatButton.GestureRecognizers>
- <callControls:FlatButton.Triggers>
- <DataTrigger TargetType="callControls:FlatButton" Binding="{Binding IsChecked, Source={x:Reference This}}" Value="True">
+ <CallControls:FlatButton.Triggers>
+ <DataTrigger TargetType="CallControls:FlatButton" Binding="{Binding IsChecked, Source={x:Reference This}}" Value="True">
<Setter Property="ImageColor" Value="{Binding CheckOnColor, Source={x:Reference This}}" />
<Setter Property="TextColor" Value="{Binding CheckOnColor, Source={x:Reference This}}" />
</DataTrigger>
- </callControls:FlatButton.Triggers>
+ </CallControls:FlatButton.Triggers>
<ContentView WidthRequest="140" HeightRequest="6" Margin="0,10,0,0" HorizontalOptions="Center" VerticalOptions="Start"
BackgroundColor="{Binding CheckOffColor, Source={x:Reference This}}">
@@ -29,4 +29,4 @@
</DataTrigger>
</ContentView.Triggers>
</ContentView>
-</callControls:FlatButton> \ No newline at end of file
+</CallControls:FlatButton> \ No newline at end of file
diff --git a/CallApp.Tizen/Call/Controls/FlatCheckbox.xaml.cs b/CallApp.Tizen/Call/View/Controls/FlatCheckbox.xaml.cs
index 68eff67..7937830 100644
--- a/CallApp.Tizen/Call/Controls/FlatCheckbox.xaml.cs
+++ b/CallApp.Tizen/Call/View/Controls/FlatCheckbox.xaml.cs
@@ -17,7 +17,7 @@
using System;
using Xamarin.Forms;
-namespace CallApp.Tizen.Call.Controls
+namespace CallApp.Tizen.Call.View.Controls
{
/// <summary>
/// Partial class of FlatCheckbox.xaml
diff --git a/CallApp.Tizen/Call/Controls/Keypad.xaml b/CallApp.Tizen/Call/View/Controls/Keypad.xaml
index ccf108d..474179c 100644
--- a/CallApp.Tizen/Call/Controls/Keypad.xaml
+++ b/CallApp.Tizen/Call/View/Controls/Keypad.xaml
@@ -1,15 +1,15 @@
<?xml version="1.0" encoding="UTF-8"?>
<ContentView xmlns="http://xamarin.com/schemas/2014/forms"
xmlns:x="http://schemas.microsoft.com/winfx/2009/xaml"
- x:Class="CallApp.Tizen.Call.Controls.Keypad"
- xmlns:callControls="clr-namespace:CallApp.Tizen.Call.Controls"
- xmlns:commonControls="clr-namespace:CallApp.Tizen.Common.Controls">
+ x:Class="CallApp.Tizen.Call.View.Controls.Keypad"
+ xmlns:CallControls="clr-namespace:CallApp.Tizen.Call.View.Controls"
+ xmlns:TizenUtilityControls="clr-namespace:Tizen.Utility.Controls">
<ContentView.Resources>
<ResourceDictionary>
<Color x:Key="KeypadButtonBorderColor">#FFD9D9D9</Color>
- <Style TargetType="callControls:KeypadButton">
+ <Style TargetType="CallControls:KeypadButton">
<Setter Property="HeightRequest" Value="130" />
</Style>
@@ -20,7 +20,7 @@
</ResourceDictionary>
</ContentView.Resources>
- <commonControls:CustomGrid>
+ <TizenUtilityControls:CustomGrid>
<Grid.ColumnDefinitions>
<ColumnDefinition Width="*" />
<ColumnDefinition Width="*" />
@@ -35,41 +35,41 @@
</Grid.RowDefinitions>
<Frame Grid.Column="0" Grid.Row="0" Padding="0,0,2,2">
- <callControls:KeypadButton NumberImage="keypad_number_01.png" KeyImage="keypad_english_13.png" />
+ <CallControls:KeypadButton NumberImage="keypad_number_01.png" KeyImage="keypad_english_13.png" />
</Frame>
<Frame Grid.Column="1" Grid.Row="0" Padding="0,0,2,2">
- <callControls:KeypadButton NumberImage="keypad_number_02.png" KeyImage="keypad_english_01.png" />
+ <CallControls:KeypadButton NumberImage="keypad_number_02.png" KeyImage="keypad_english_01.png" />
</Frame>
<Frame Grid.Column="2" Grid.Row="0" Padding="0,0,0,2">
- <callControls:KeypadButton NumberImage="keypad_number_03.png" KeyImage="keypad_english_02.png" />
+ <CallControls:KeypadButton NumberImage="keypad_number_03.png" KeyImage="keypad_english_02.png" />
</Frame>
<Frame Grid.Column="0" Grid.Row="1" Padding="0,0,2,2">
- <callControls:KeypadButton NumberImage="keypad_number_04.png" KeyImage="keypad_english_03.png" />
+ <CallControls:KeypadButton NumberImage="keypad_number_04.png" KeyImage="keypad_english_03.png" />
</Frame>
<Frame Grid.Column="1" Grid.Row="1" Padding="0,0,2,2">
- <callControls:KeypadButton NumberImage="keypad_number_05.png" KeyImage="keypad_english_04.png" />
+ <CallControls:KeypadButton NumberImage="keypad_number_05.png" KeyImage="keypad_english_04.png" />
</Frame>
<Frame Grid.Column="2" Grid.Row="1" Padding="0,0,0,2">
- <callControls:KeypadButton NumberImage="keypad_number_06.png" KeyImage="keypad_english_05.png" />
+ <CallControls:KeypadButton NumberImage="keypad_number_06.png" KeyImage="keypad_english_05.png" />
</Frame>
<Frame Grid.Column="0" Grid.Row="2" Padding="0,0,2,2">
- <callControls:KeypadButton NumberImage="keypad_number_07.png" KeyImage="keypad_english_06.png" />
+ <CallControls:KeypadButton NumberImage="keypad_number_07.png" KeyImage="keypad_english_06.png" />
</Frame>
<Frame Grid.Column="1" Grid.Row="2" Padding="0,0,2,2">
- <callControls:KeypadButton NumberImage="keypad_number_08.png" KeyImage="keypad_english_07.png" />
+ <CallControls:KeypadButton NumberImage="keypad_number_08.png" KeyImage="keypad_english_07.png" />
</Frame>
<Frame Grid.Column="2" Grid.Row="2" Padding="0,0,0,2">
- <callControls:KeypadButton NumberImage="keypad_number_09.png" KeyImage="keypad_english_08.png" />
+ <CallControls:KeypadButton NumberImage="keypad_number_09.png" KeyImage="keypad_english_08.png" />
</Frame>
<Frame Grid.Column="0" Grid.Row="3" Padding="0,0,2,0">
- <callControls:KeypadButton NumberImage="keypad_number_asterisk.png" />
+ <CallControls:KeypadButton NumberImage="keypad_number_asterisk.png" />
</Frame>
<Frame Grid.Column="1" Grid.Row="3" Padding="0,0,2,0">
- <callControls:KeypadButton NumberImage="keypad_number_00.png" KeyImage="keypad_english_10.png" />
+ <CallControls:KeypadButton NumberImage="keypad_number_00.png" KeyImage="keypad_english_10.png" />
</Frame>
- <callControls:KeypadButton Grid.Column="2" Grid.Row="3" NumberImage="keypad_number_sharp.png" />
- </commonControls:CustomGrid>
+ <CallControls:KeypadButton Grid.Column="2" Grid.Row="3" NumberImage="keypad_number_sharp.png" />
+ </TizenUtilityControls:CustomGrid>
</ContentView> \ No newline at end of file
diff --git a/CallApp.Tizen/Call/Controls/Keypad.xaml.cs b/CallApp.Tizen/Call/View/Controls/Keypad.xaml.cs
index 8e5d79a..e2259f2 100644
--- a/CallApp.Tizen/Call/Controls/Keypad.xaml.cs
+++ b/CallApp.Tizen/Call/View/Controls/Keypad.xaml.cs
@@ -16,7 +16,7 @@
using Xamarin.Forms;
-namespace CallApp.Tizen.Call.Controls
+namespace CallApp.Tizen.Call.View.Controls
{
/// <summary>
/// Partial class of Keypad.xaml
diff --git a/CallApp.Tizen/Call/Controls/KeypadButton.xaml b/CallApp.Tizen/Call/View/Controls/KeypadButton.xaml
index 1189ac5..49beda7 100644
--- a/CallApp.Tizen/Call/Controls/KeypadButton.xaml
+++ b/CallApp.Tizen/Call/View/Controls/KeypadButton.xaml
@@ -1,32 +1,32 @@
<?xml version="1.0" encoding="UTF-8"?>
-<callControls:FlatButton xmlns="http://xamarin.com/schemas/2014/forms"
+<CallControls:FlatButton xmlns="http://xamarin.com/schemas/2014/forms"
xmlns:x="http://schemas.microsoft.com/winfx/2009/xaml"
- x:Class="CallApp.Tizen.Call.Controls.KeypadButton"
+ x:Class="CallApp.Tizen.Call.View.Controls.KeypadButton"
x:Name="This"
- xmlns:callControls="clr-namespace:CallApp.Tizen.Call.Controls"
- xmlns:commonControls="clr-namespace:CallApp.Tizen.Common.Controls"
+ xmlns:CallControls="clr-namespace:CallApp.Tizen.Call.View.Controls"
+ xmlns:TizenUtilityControls="clr-namespace:Tizen.Utility.Controls"
NormalColor="{StaticResource KeypadButtonNormalColor}">
- <callControls:FlatButton.Resources>
+ <CallControls:FlatButton.Resources>
<ResourceDictionary>
<Color x:Key="KeyImageColor">#CC333333</Color>
<Color x:Key="KeypadButtonNormalColor">#FFFAFAFA</Color>
<Color x:Key="NumberImageColor">#D9000000</Color>
- <Style x:Key="NumberImageStyle" TargetType="commonControls:CustomImage">
+ <Style x:Key="NumberImageStyle" TargetType="TizenUtilityControls:CustomImage">
<Setter Property="HeightRequest" Value="71" />
<Setter Property="BlendingColor" Value="{StaticResource NumberImageColor}" />
</Style>
- <Style x:Key="KeyImageStyle" TargetType="commonControls:CustomImage">
+ <Style x:Key="KeyImageStyle" TargetType="TizenUtilityControls:CustomImage">
<Setter Property="HeightRequest" Value="36" />
<Setter Property="BlendingColor" Value="{StaticResource KeyImageColor}" />
</Style>
</ResourceDictionary>
- </callControls:FlatButton.Resources>
+ </CallControls:FlatButton.Resources>
<StackLayout VerticalOptions="Center">
- <commonControls:CustomImage Source="{Binding NumberImage, Source={x:Reference This}}" Style="{StaticResource NumberImageStyle}" />
- <commonControls:CustomImage Source="{Binding KeyImage, Source={x:Reference This}}" Style="{StaticResource KeyImageStyle}" />
+ <TizenUtilityControls:CustomImage Source="{Binding NumberImage, Source={x:Reference This}}" Style="{StaticResource NumberImageStyle}" />
+ <TizenUtilityControls:CustomImage Source="{Binding KeyImage, Source={x:Reference This}}" Style="{StaticResource KeyImageStyle}" />
</StackLayout>
-</callControls:FlatButton> \ No newline at end of file
+</CallControls:FlatButton> \ No newline at end of file
diff --git a/CallApp.Tizen/Call/Controls/KeypadButton.xaml.cs b/CallApp.Tizen/Call/View/Controls/KeypadButton.xaml.cs
index 532a3c0..31e6ffe 100644
--- a/CallApp.Tizen/Call/Controls/KeypadButton.xaml.cs
+++ b/CallApp.Tizen/Call/View/Controls/KeypadButton.xaml.cs
@@ -16,7 +16,7 @@
using Xamarin.Forms;
-namespace CallApp.Tizen.Call.Controls
+namespace CallApp.Tizen.Call.View.Controls
{
/// <summary>
/// Partial class of KeypadButton.xaml
diff --git a/CallApp.Tizen/Call/View/Controls/MergeSwapPanel.xaml b/CallApp.Tizen/Call/View/Controls/MergeSwapPanel.xaml
new file mode 100644
index 0000000..ac1d1e3
--- /dev/null
+++ b/CallApp.Tizen/Call/View/Controls/MergeSwapPanel.xaml
@@ -0,0 +1,17 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<ContentView xmlns="http://xamarin.com/schemas/2014/forms"
+ xmlns:x="http://schemas.microsoft.com/winfx/2009/xaml"
+ x:Class="CallApp.Tizen.Call.View.Controls.MergeSwapPanel"
+ xmlns:CallControls="clr-namespace:CallApp.Tizen.Call.View.Controls"
+ xmlns:Localization="clr-namespace:CallApp.Tizen.Localization">
+
+ <StackLayout>
+ <CallControls:ContactInfoPanel LayoutType="Top" StatusText="{x:Static Localization:Localization.OnHold}"
+ PrimaryText="Test" SecondaryText="Test" />
+
+ <StackLayout HeightRequest="122" Orientation="Horizontal">
+ <CallControls:FlatButton HorizontalOptions="FillAndExpand" Image="call_multi_ic_merge.png" Text="{x:Static Localization:Localization.Merge}" />
+ <CallControls:FlatButton HorizontalOptions="FillAndExpand" Image="call_multi_ic_swap.png" Text="{x:Static Localization:Localization.Swap}" />
+ </StackLayout>
+ </StackLayout>
+</ContentView> \ No newline at end of file
diff --git a/CallApp.Tizen/Call/Controls/MergeSwapPanel.xaml.cs b/CallApp.Tizen/Call/View/Controls/MergeSwapPanel.xaml.cs
index dd97287..f9b6aad 100644
--- a/CallApp.Tizen/Call/Controls/MergeSwapPanel.xaml.cs
+++ b/CallApp.Tizen/Call/View/Controls/MergeSwapPanel.xaml.cs
@@ -16,7 +16,7 @@
using Xamarin.Forms;
-namespace CallApp.Tizen.Call.Controls
+namespace CallApp.Tizen.Call.View.Controls
{
/// <summary>
/// Partial class of MergeSwapPanel.xaml
diff --git a/CallApp.Tizen/Call/Controls/MiniActiveCallPanel.xaml b/CallApp.Tizen/Call/View/Controls/MiniActiveCallPanel.xaml
index 3200b75..5e8f031 100644
--- a/CallApp.Tizen/Call/Controls/MiniActiveCallPanel.xaml
+++ b/CallApp.Tizen/Call/View/Controls/MiniActiveCallPanel.xaml
@@ -1,13 +1,12 @@
<?xml version="1.0" encoding="UTF-8"?>
<ContentView xmlns="http://xamarin.com/schemas/2014/forms"
xmlns:x="http://schemas.microsoft.com/winfx/2009/xaml"
- x:Class="CallApp.Tizen.Call.Controls.MiniActiveCallPanel"
+ x:Class="CallApp.Tizen.Call.View.Controls.MiniActiveCallPanel"
x:Name="This"
- xmlns:callControls="clr-namespace:CallApp.Tizen.Call.Controls"
- xmlns:callThemes="clr-namespace:CallApp.Tizen.Call.Themes">
+ xmlns:CallControls="clr-namespace:CallApp.Tizen.Call.View.Controls">
<ContentView.Resources>
- <ResourceDictionary MergedWith="callThemes:CallTheme">
+ <ResourceDictionary>
<Color x:Key="ContactNameTextColor">#FF000000</Color>
<Color x:Key="TimeTextColor">#FF808080</Color>
<Color x:Key="OptionButtonNormalColor">#FF3DB7CB</Color>
@@ -24,21 +23,21 @@
TextColor="{StaticResource TimeTextColor}" FontSize="21" Text="00:00" />
</StackLayout>
- <callControls:AnimatedCircleButton Margin="56,41,0,0" Radius="90"
+ <CallControls:AnimatedCircleButton Margin="56,41,0,0" Radius="90"
NormalColor="{StaticResource OptionButtonNormalColor}"
PressColor="{StaticResource OptionButtonPressColor}"
DimColor="{StaticResource OptionButtonDimColor}"
Image="call_noti_btn_speaker.png" />
- <callControls:AnimatedCircleButton Margin="32,41,0,0" Radius="90"
+ <CallControls:AnimatedCircleButton Margin="32,41,0,0" Radius="90"
NormalColor="{StaticResource OptionButtonNormalColor}"
PressColor="{StaticResource OptionButtonPressColor}"
DimColor="{StaticResource OptionButtonDimColor}"
Image="call_noti_btn_resume.png" />
- <callControls:AnimatedCircleButton Margin="32,41,0,0" Radius="90"
- NormalColor="{StaticResource CallButtonCircleRejectNormalColor}"
- PressColor="{StaticResource CallButtonCircleRejectPressColor}"
+ <CallControls:AnimatedCircleButton Margin="32,41,0,0" Radius="90"
+ NormalColor="{StaticResource CircleButtonRejectNormalColor}"
+ PressColor="{StaticResource CircleButtonRejectPressColor}"
Image="call_btn_ic_reject.png" />
</StackLayout>
</ControlTemplate>
@@ -55,14 +54,14 @@
TextColor="{StaticResource TimeTextColor}" FontSize="21" Text="00:00" />
</StackLayout>
- <callControls:AnimatedCircleButton Margin="56,41,0,0" Radius="90"
- NormalColor="{StaticResource CallButtonCircleAcceptNormalColor}"
- PressColor="{StaticResource CallButtonCircleAcceptPressColor}"
+ <CallControls:AnimatedCircleButton Margin="56,41,0,0" Radius="90"
+ NormalColor="{StaticResource CircleButtonAcceptNormalColor}"
+ PressColor="{StaticResource CircleButtonAcceptPressColor}"
Image="call_btn_ic_accept.png" />
- <callControls:AnimatedCircleButton Margin="32,41,0,0" Radius="90"
- NormalColor="{StaticResource CallButtonCircleRejectNormalColor}"
- PressColor="{StaticResource CallButtonCircleRejectPressColor}"
+ <CallControls:AnimatedCircleButton Margin="32,41,0,0" Radius="90"
+ NormalColor="{StaticResource CircleButtonRejectNormalColor}"
+ PressColor="{StaticResource CircleButtonRejectPressColor}"
Image="call_btn_ic_reject.png" />
</StackLayout>
</ControlTemplate>
diff --git a/CallApp.Tizen/Call/Controls/MiniActiveCallPanel.xaml.cs b/CallApp.Tizen/Call/View/Controls/MiniActiveCallPanel.xaml.cs
index 42d9743..3ebdc7e 100644
--- a/CallApp.Tizen/Call/Controls/MiniActiveCallPanel.xaml.cs
+++ b/CallApp.Tizen/Call/View/Controls/MiniActiveCallPanel.xaml.cs
@@ -16,7 +16,7 @@
using Xamarin.Forms;
-namespace CallApp.Tizen.Call.Controls
+namespace CallApp.Tizen.Call.View.Controls
{
/// <summary>
/// Partial class of MiniActiveCallPanel.xaml
diff --git a/CallApp.Tizen/Call/Controls/ProximityControl.xaml b/CallApp.Tizen/Call/View/Controls/ProximityControl.xaml
index 7bad64e..04916ac 100644
--- a/CallApp.Tizen/Call/Controls/ProximityControl.xaml
+++ b/CallApp.Tizen/Call/View/Controls/ProximityControl.xaml
@@ -1,9 +1,9 @@
<?xml version="1.0" encoding="UTF-8"?>
<ContentView xmlns="http://xamarin.com/schemas/2014/forms"
xmlns:x="http://schemas.microsoft.com/winfx/2009/xaml"
- x:Class="CallApp.Tizen.Call.Controls.ProximityControl"
+ x:Class="CallApp.Tizen.Call.View.Controls.ProximityControl"
x:Name="This"
- xmlns:commonControls="clr-namespace:CallApp.Tizen.Common.Controls"
+ xmlns:TizenUtilityControls="clr-namespace:Tizen.Utility.Controls"
IsVisible="False">
<ContentView.Triggers>
@@ -12,7 +12,7 @@
</DataTrigger>
</ContentView.Triggers>
- <commonControls:CustomGrid BackgroundColor="Black" Opacity="0.7">
+ <TizenUtilityControls:CustomGrid BackgroundColor="Black" Opacity="0.7">
<Image WidthRequest="242" HeightRequest="242" HorizontalOptions="Center" VerticalOptions="Center" Source="call_lock_icon.png" />
- </commonControls:CustomGrid>
+ </TizenUtilityControls:CustomGrid>
</ContentView> \ No newline at end of file
diff --git a/CallApp.Tizen/Call/Controls/ProximityControl.xaml.cs b/CallApp.Tizen/Call/View/Controls/ProximityControl.xaml.cs
index 2f29db5..1f5b839 100644
--- a/CallApp.Tizen/Call/Controls/ProximityControl.xaml.cs
+++ b/CallApp.Tizen/Call/View/Controls/ProximityControl.xaml.cs
@@ -17,7 +17,7 @@
using Tizen.Sensor;
using Xamarin.Forms;
-namespace CallApp.Tizen.Call.Controls
+namespace CallApp.Tizen.Call.View.Controls
{
/// <summary>
/// Partial class of ProximityControl.xaml
diff --git a/CallApp.Tizen/Call/Controls/RejectCallPanel.xaml b/CallApp.Tizen/Call/View/Controls/RejectCallPanel.xaml
index 09abcee..5f433de 100644
--- a/CallApp.Tizen/Call/Controls/RejectCallPanel.xaml
+++ b/CallApp.Tizen/Call/View/Controls/RejectCallPanel.xaml
@@ -1,19 +1,18 @@
<?xml version="1.0" encoding="utf-8" ?>
<ContentView xmlns="http://xamarin.com/schemas/2014/forms"
xmlns:x="http://schemas.microsoft.com/winfx/2009/xaml"
- x:Class="CallApp.Tizen.Call.Controls.RejectCallPanel"
+ x:Class="CallApp.Tizen.Call.View.Controls.RejectCallPanel"
x:Name="This"
- xmlns:callThemes="clr-namespace:CallApp.Tizen.Call.Themes"
- xmlns:commonControls="clr-namespace:CallApp.Tizen.Common.Controls"
- xmlns:loc="clr-namespace:CallApp.Tizen.loc">
+ xmlns:Localization="clr-namespace:CallApp.Tizen.Localization"
+ xmlns:TizenUtilityControls="clr-namespace:Tizen.Utility.Controls">
<ContentView.Resources>
- <ResourceDictionary MergedWith="callThemes:CallTheme">
+ <ResourceDictionary>
<Color x:Key="TopInlineButtonNormalColor">#FF029DB7</Color>
<Color x:Key="BottomInlineButtonNormalColor">#FFFAFAFA</Color>
<ControlTemplate x:Key="TopOpenDirectionPanel">
- <commonControls:CustomGrid HeightRequest="{TemplateBinding DefaultHeight}">
+ <TizenUtilityControls:CustomGrid HeightRequest="{TemplateBinding DefaultHeight}">
<Grid.RowDefinitions>
<RowDefinition Height="Auto" />
<RowDefinition Height="78" />
@@ -21,26 +20,26 @@
<RowDefinition Height="Auto" />
</Grid.RowDefinitions>
- <commonControls:GesturesContainer Grid.Row="0" PanUpdated="OnPanUpdated">
- <commonControls:CustomGrid>
+ <TizenUtilityControls:GesturesContainer Grid.Row="0" PanUpdated="OnPanUpdated">
+ <TizenUtilityControls:CustomGrid>
<Grid.RowDefinitions>
<RowDefinition Height="12" />
<RowDefinition Height="18" />
<RowDefinition Height="20" />
</Grid.RowDefinitions>
- <commonControls:CustomImage Grid.Row="1" BlendingColor="{StaticResource TopInlineButtonNormalColor}" Source="call_inline_btn_open.png">
- <commonControls:CustomImage.Triggers>
- <DataTrigger TargetType="commonControls:CustomImage" Binding="{TemplateBinding IsOpen}" Value="True">
+ <TizenUtilityControls:CustomImage Grid.Row="1" BlendingColor="{StaticResource TopInlineButtonNormalColor}" Source="call_inline_btn_open.png">
+ <TizenUtilityControls:CustomImage.Triggers>
+ <DataTrigger TargetType="TizenUtilityControls:CustomImage" Binding="{TemplateBinding IsOpen}" Value="True">
<Setter Property="Source" Value="call_inline_btn_close.png" />
</DataTrigger>
- </commonControls:CustomImage.Triggers>
- </commonControls:CustomImage>
- </commonControls:CustomGrid>
- </commonControls:GesturesContainer>
+ </TizenUtilityControls:CustomImage.Triggers>
+ </TizenUtilityControls:CustomImage>
+ </TizenUtilityControls:CustomGrid>
+ </TizenUtilityControls:GesturesContainer>
<Label Grid.Row="1" HorizontalOptions="Center" VerticalOptions="Center"
- TextColor="{StaticResource TopInlineButtonNormalColor}" Text="{x:Static loc:loc.RejectCallWithMessage}">
+ TextColor="{StaticResource TopInlineButtonNormalColor}" Text="{x:Static Localization:Localization.RejectCallWithMessage}">
<Label.Triggers>
<DataTrigger TargetType="Label" Binding="{TemplateBinding IsOpen}" Value="True">
<Setter Property="IsVisible" Value="False" />
@@ -49,7 +48,7 @@
</Label>
<Button Grid.Row="1" HorizontalOptions="Center" VerticalOptions="Center"
- Text="{x:Static loc:loc.ComposeMessageToSend}" IsVisible="False">
+ Text="{x:Static Localization:Localization.ComposeMessageToSend}" IsVisible="False">
<Button.Triggers>
<DataTrigger TargetType="Button" Binding="{TemplateBinding IsOpen}" Value="True">
<Setter Property="IsVisible" Value="True" />
@@ -58,36 +57,36 @@
</Button>
<ContentPresenter Grid.Row="3" />
- </commonControls:CustomGrid>
+ </TizenUtilityControls:CustomGrid>
</ControlTemplate>
<ControlTemplate x:Key="BottomOpenDirectionPanel">
- <commonControls:CustomGrid HeightRequest="{TemplateBinding DefaultHeight}">
+ <TizenUtilityControls:CustomGrid HeightRequest="{TemplateBinding DefaultHeight}">
<Grid.RowDefinitions>
<RowDefinition Height="Auto" />
<RowDefinition Height="Auto" />
</Grid.RowDefinitions>
- <commonControls:GesturesContainer Grid.Row="0" PanUpdated="OnPanUpdated">
- <commonControls:CustomGrid>
+ <TizenUtilityControls:GesturesContainer Grid.Row="0" PanUpdated="OnPanUpdated">
+ <TizenUtilityControls:CustomGrid>
<Grid.RowDefinitions>
<RowDefinition Height="12" />
<RowDefinition Height="18" />
<RowDefinition Height="20" />
</Grid.RowDefinitions>
- <commonControls:CustomImage Grid.Row="1" BlendingColor="{StaticResource BottomInlineButtonNormalColor}" Source="call_inline_btn_open.png">
- <commonControls:CustomImage.Triggers>
- <DataTrigger TargetType="commonControls:CustomImage" Binding="{TemplateBinding IsOpen}" Value="True">
+ <TizenUtilityControls:CustomImage Grid.Row="1" BlendingColor="{StaticResource BottomInlineButtonNormalColor}" Source="call_inline_btn_open.png">
+ <TizenUtilityControls:CustomImage.Triggers>
+ <DataTrigger TargetType="TizenUtilityControls:CustomImage" Binding="{TemplateBinding IsOpen}" Value="True">
<Setter Property="IsVisible" Value="False" />
</DataTrigger>
- </commonControls:CustomImage.Triggers>
- </commonControls:CustomImage>
- </commonControls:CustomGrid>
- </commonControls:GesturesContainer>
+ </TizenUtilityControls:CustomImage.Triggers>
+ </TizenUtilityControls:CustomImage>
+ </TizenUtilityControls:CustomGrid>
+ </TizenUtilityControls:GesturesContainer>
<ContentPresenter Grid.Row="1" />
- </commonControls:CustomGrid>
+ </TizenUtilityControls:CustomGrid>
</ControlTemplate>
</ResourceDictionary>
</ContentView.Resources>
diff --git a/CallApp.Tizen/Call/Controls/RejectCallPanel.xaml.cs b/CallApp.Tizen/Call/View/Controls/RejectCallPanel.xaml.cs
index 942d321..bb5fb49 100644
--- a/CallApp.Tizen/Call/Controls/RejectCallPanel.xaml.cs
+++ b/CallApp.Tizen/Call/View/Controls/RejectCallPanel.xaml.cs
@@ -16,7 +16,7 @@
using Xamarin.Forms;
-namespace CallApp.Tizen.Call.Controls
+namespace CallApp.Tizen.Call.View.Controls
{
/// <summary>
/// Partial class of RejectCallPanel.xaml
diff --git a/CallApp.Tizen/Call/Controls/RejectMessageList.xaml b/CallApp.Tizen/Call/View/Controls/RejectMessageList.xaml
index 22727a0..d49b7fe 100644
--- a/CallApp.Tizen/Call/Controls/RejectMessageList.xaml
+++ b/CallApp.Tizen/Call/View/Controls/RejectMessageList.xaml
@@ -1,15 +1,10 @@
<?xml version="1.0" encoding="UTF-8"?>
<ContentView xmlns="http://xamarin.com/schemas/2014/forms"
xmlns:x="http://schemas.microsoft.com/winfx/2009/xaml"
- x:Class="CallApp.Tizen.Call.Controls.RejectMessageList"
+ x:Class="CallApp.Tizen.Call.View.Controls.RejectMessageList"
x:Name="This"
- xmlns:callThemes="clr-namespace:CallApp.Tizen.Call.Themes"
- xmlns:commonControls="clr-namespace:CallApp.Tizen.Common.Controls"
- xmlns:commonInput="clr-namespace:CallApp.Tizen.Common.Input">
-
- <ContentView.Resources>
- <ResourceDictionary MergedWith="callThemes:CallTheme" />
- </ContentView.Resources>
+ xmlns:TizenUtilityControls="clr-namespace:Tizen.Utility.Controls"
+ xmlns:TizenUtilityInput="clr-namespace:Tizen.Utility.Input">
<ListView ItemsSource="{Binding Items, Source={x:Reference This}}">
<ListView.ItemTemplate>
@@ -17,7 +12,7 @@
<ViewCell>
<ContentView HeightRequest="120" BackgroundColor="{Binding NormalColor, Source={x:Reference This}}">
<ContentView.Triggers>
- <Trigger TargetType="ContentView" Property="commonInput:GesturesInput.IsTap" Value="True">
+ <Trigger TargetType="ContentView" Property="TizenUtilityInput:GesturesInput.IsTap" Value="True">
<Setter Property="BackgroundColor" Value="{Binding PressColor, Source={x:Reference This}}" />
</Trigger>
</ContentView.Triggers>
diff --git a/CallApp.Tizen/Call/Controls/RejectMessageList.xaml.cs b/CallApp.Tizen/Call/View/Controls/RejectMessageList.xaml.cs
index 5625414..6934e63 100644
--- a/CallApp.Tizen/Call/Controls/RejectMessageList.xaml.cs
+++ b/CallApp.Tizen/Call/View/Controls/RejectMessageList.xaml.cs
@@ -17,7 +17,7 @@
using System.Collections;
using Xamarin.Forms;
-namespace CallApp.Tizen.Call.Controls
+namespace CallApp.Tizen.Call.View.Controls
{
/// <summary>
/// Partial class of RejectMessageList.xaml
diff --git a/CallApp.Tizen/Call/Controls/Renderers/AnimatedCircleButtonRenderer.cs b/CallApp.Tizen/Call/View/Controls/Renderers/AnimatedCircleButtonRenderer.cs
index 5fb04dd..13e402f 100644
--- a/CallApp.Tizen/Call/Controls/Renderers/AnimatedCircleButtonRenderer.cs
+++ b/CallApp.Tizen/Call/View/Controls/Renderers/AnimatedCircleButtonRenderer.cs
@@ -14,13 +14,13 @@
* limitations under the License.
*/
-using CallApp.Tizen.Call.Controls;
-using CallApp.Tizen.Call.Controls.Renderers;
+using CallApp.Tizen.Call.View.Controls;
+using CallApp.Tizen.Call.View.Controls.Renderers;
using Xamarin.Forms;
using Xamarin.Forms.Platform.Tizen;
[assembly: ExportRenderer(typeof(AnimatedCircleButton), typeof(AnimatedCircleButtonRenderer))]
-namespace CallApp.Tizen.Call.Controls.Renderers
+namespace CallApp.Tizen.Call.View.Controls.Renderers
{
/// <summary>
/// A renderer for AnimatedCircleButton
diff --git a/CallApp.Tizen/CallApp.Tizen.csproj b/CallApp.Tizen/CallApp.Tizen.csproj
index dfd17c4..6df77e4 100644
--- a/CallApp.Tizen/CallApp.Tizen.csproj
+++ b/CallApp.Tizen/CallApp.Tizen.csproj
@@ -51,87 +51,87 @@
<None Include="tizen-manifest.xml" />
</ItemGroup>
<ItemGroup>
- <Compile Include="CallApp.cs" />
+ <Compile Include="App.xaml.cs">
+ <DependentUpon>App.xaml</DependentUpon>
+ </Compile>
<Compile Include="CallApp.Tizen.cs" />
- <Compile Include="Call\Controls\AnimatedCircleButton.xaml.cs">
+ <Compile Include="Call\View\Controls\AnimatedCircleButton.xaml.cs">
<DependentUpon>AnimatedCircleButton.xaml</DependentUpon>
</Compile>
- <Compile Include="Call\Controls\CallHandlingPanel.xaml.cs">
+ <Compile Include="Call\View\Controls\CallHandlingPanel.xaml.cs">
<DependentUpon>CallHandlingPanel.xaml</DependentUpon>
</Compile>
- <Compile Include="Call\Controls\Keypad.xaml.cs">
+ <Compile Include="Call\View\Controls\Keypad.xaml.cs">
<DependentUpon>Keypad.xaml</DependentUpon>
</Compile>
- <Compile Include="Call\Controls\KeypadButton.xaml.cs">
+ <Compile Include="Call\View\Controls\KeypadButton.xaml.cs">
<DependentUpon>KeypadButton.xaml</DependentUpon>
</Compile>
- <Compile Include="Call\Controls\MergeSwapPanel.xaml.cs">
+ <Compile Include="Call\View\Controls\MergeSwapPanel.xaml.cs">
<DependentUpon>MergeSwapPanel.xaml</DependentUpon>
</Compile>
- <Compile Include="Call\Controls\MiniActiveCallPanel.xaml.cs">
+ <Compile Include="Call\View\Controls\MiniActiveCallPanel.xaml.cs">
<DependentUpon>MiniActiveCallPanel.xaml</DependentUpon>
</Compile>
- <Compile Include="Call\Controls\RejectMessageList.xaml.cs">
+ <Compile Include="Call\View\Controls\RejectMessageList.xaml.cs">
<DependentUpon>RejectMessageList.xaml</DependentUpon>
</Compile>
- <Compile Include="Call\Controls\ConferenceCallManageList.xaml.cs">
+ <Compile Include="Call\View\Controls\ConferenceCallManageList.xaml.cs">
<DependentUpon>ConferenceCallManageList.xaml</DependentUpon>
</Compile>
- <Compile Include="Call\Controls\ContactInfoPanel.xaml.cs">
+ <Compile Include="Call\View\Controls\ContactInfoPanel.xaml.cs">
<DependentUpon>ContactInfoPanel.xaml</DependentUpon>
</Compile>
- <Compile Include="Call\Controls\FlatButton.xaml.cs">
+ <Compile Include="Call\View\Controls\FlatButton.xaml.cs">
<DependentUpon>FlatButton.xaml</DependentUpon>
</Compile>
- <Compile Include="Call\Controls\FlatCheckbox.xaml.cs">
+ <Compile Include="Call\View\Controls\FlatCheckbox.xaml.cs">
<DependentUpon>FlatCheckbox.xaml</DependentUpon>
</Compile>
- <Compile Include="Call\Controls\ProximityControl.xaml.cs">
+ <Compile Include="Call\View\Controls\ProximityControl.xaml.cs">
<DependentUpon>ProximityControl.xaml</DependentUpon>
</Compile>
- <Compile Include="Call\Controls\RejectCallPanel.xaml.cs">
+ <Compile Include="Call\View\Controls\RejectCallPanel.xaml.cs">
<DependentUpon>RejectCallPanel.xaml</DependentUpon>
</Compile>
- <Compile Include="Call\Controls\Renderers\AnimatedCircleButtonRenderer.cs" />
- <Compile Include="Call\Pages\ConferenceCallManagePage.xaml.cs">
+ <Compile Include="Call\View\Controls\Renderers\AnimatedCircleButtonRenderer.cs" />
+ <Compile Include="Call\View\ConferenceCallManagePage.xaml.cs">
<DependentUpon>ConferenceCallManagePage.xaml</DependentUpon>
</Compile>
- <Compile Include="Call\Themes\CallTheme.xaml.cs">
- <DependentUpon>CallTheme.xaml</DependentUpon>
+ <Compile Include="Common\Themes\CommonTheme.xaml.cs">
+ <DependentUpon>CommonTheme.xaml</DependentUpon>
</Compile>
- <Compile Include="Common\Controls\CustomGrid.xaml.cs">
+ <Compile Include="Tizen.Utility\Controls\CustomGrid.xaml.cs">
<DependentUpon>CustomGrid.xaml</DependentUpon>
</Compile>
- <Compile Include="Common\Controls\CustomImage.xaml.cs">
+ <Compile Include="Tizen.Utility\Controls\CustomImage.xaml.cs">
<DependentUpon>CustomImage.xaml</DependentUpon>
</Compile>
- <Compile Include="Common\Controls\GesturesContainer.xaml.cs">
+ <Compile Include="Tizen.Utility\Controls\GesturesContainer.xaml.cs">
<DependentUpon>GesturesContainer.xaml</DependentUpon>
</Compile>
- <Compile Include="Common\Controls\Renderers\CustomImageRenderer.cs" />
- <Compile Include="Common\Converters\IsStringEmptyConverter.cs" />
- <Compile Include="Common\Converters\IsNullConverter.cs" />
- <Compile Include="Common\Helpers\BaseModel.cs" />
- <Compile Include="Common\Helpers\Logger.cs" />
- <Compile Include="Common\Helpers\PageNavigator.cs" />
- <Compile Include="Common\Input\AttachedTapCommand.cs" />
- <Compile Include="Common\Input\GesturesInput.cs" />
- <Compile Include="loc\loc.Designer.cs">
+ <Compile Include="Tizen.Utility\Controls\Renderers\CustomImageRenderer.cs" />
+ <Compile Include="Tizen.Utility\Converters\IsStringEmptyConverter.cs" />
+ <Compile Include="Tizen.Utility\Converters\IsNullConverter.cs" />
+ <Compile Include="Tizen.Utility\Helpers\BaseModel.cs" />
+ <Compile Include="Tizen.Utility\Helpers\Logger.cs" />
+ <Compile Include="Tizen.Utility\Helpers\PageNavigator.cs" />
+ <Compile Include="Tizen.Utility\Input\AttachedTapCommand.cs" />
+ <Compile Include="Tizen.Utility\Input\GesturesInput.cs" />
+ <Compile Include="loc\Localization.Designer.cs">
<AutoGen>True</AutoGen>
<DesignTime>True</DesignTime>
- <DependentUpon>loc.resx</DependentUpon>
+ <DependentUpon>Localization.resx</DependentUpon>
</Compile>
<Compile Include="Properties\AssemblyInfo.cs" />
</ItemGroup>
<ItemGroup>
+ <Folder Include="Call\Model\" />
+ <Folder Include="Call\ViewModel\" />
<Folder Include="lib\" />
</ItemGroup>
<ItemGroup>
- <Content Include="res\Call ID\168x168\call_end_photo_id_default.png" />
- <Content Include="res\Call ID\348x348\call_photo_id.png" />
- <Content Include="res\Call ID\348x348\call_photo_id_conference.png" />
<Content Include="res\Call ID\348x348\call_photo_id_emergency.png" />
- <Content Include="res\Call ID\96x96\call_photo_id_conference.png" />
<Content Include="res\call_active_ic_call.png" />
<Content Include="res\call_btn_addcall.png" />
<Content Include="res\call_btn_bluetooth.png" />
@@ -145,7 +145,6 @@
<Content Include="res\call_inline_btn_close.png" />
<Content Include="res\call_inline_btn_open.png" />
<Content Include="res\call_lock_icon.png" />
- <Content Include="res\call_manage_photo_id_mask_04.png" />
<Content Include="res\call_multi_ic_arrow.png" />
<Content Include="res\call_multi_ic_merge.png" />
<Content Include="res\call_multi_ic_swap.png" />
@@ -177,91 +176,96 @@
<Content Include="shared\res\icon.png" />
</ItemGroup>
<ItemGroup>
- <EmbeddedResource Include="loc\loc.resx">
+ <EmbeddedResource Include="loc\Localization.resx">
<Generator>PublicResXFileCodeGenerator</Generator>
- <LastGenOutput>loc.Designer.cs</LastGenOutput>
+ <LastGenOutput>Localization.Designer.cs</LastGenOutput>
<SubType>Designer</SubType>
</EmbeddedResource>
</ItemGroup>
<ItemGroup>
- <EmbeddedResource Include="Common\Controls\CustomGrid.xaml">
+ <EmbeddedResource Include="Tizen.Utility\Controls\CustomGrid.xaml">
<Generator>MSBuild:UpdateDesignTimeXaml</Generator>
</EmbeddedResource>
- <EmbeddedResource Include="Common\Controls\CustomImage.xaml">
+ <EmbeddedResource Include="Tizen.Utility\Controls\CustomImage.xaml">
<Generator>MSBuild:UpdateDesignTimeXaml</Generator>
</EmbeddedResource>
- <EmbeddedResource Include="Common\Controls\GesturesContainer.xaml">
+ <EmbeddedResource Include="Tizen.Utility\Controls\GesturesContainer.xaml">
<Generator>MSBuild:UpdateDesignTimeXaml</Generator>
</EmbeddedResource>
</ItemGroup>
<ItemGroup>
- <EmbeddedResource Include="Call\Controls\AnimatedCircleButton.xaml">
+ <EmbeddedResource Include="Call\View\Controls\AnimatedCircleButton.xaml">
<Generator>MSBuild:UpdateDesignTimeXaml</Generator>
</EmbeddedResource>
</ItemGroup>
<ItemGroup>
- <EmbeddedResource Include="Call\Controls\FlatButton.xaml">
+ <EmbeddedResource Include="Call\View\Controls\FlatButton.xaml">
<Generator>MSBuild:UpdateDesignTimeXaml</Generator>
</EmbeddedResource>
- <EmbeddedResource Include="Call\Controls\FlatCheckbox.xaml">
+ <EmbeddedResource Include="Call\View\Controls\FlatCheckbox.xaml">
<Generator>MSBuild:UpdateDesignTimeXaml</Generator>
</EmbeddedResource>
</ItemGroup>
<ItemGroup>
- <EmbeddedResource Include="Call\Themes\CallTheme.xaml">
+ <EmbeddedResource Include="Common\Themes\CommonTheme.xaml">
<Generator>MSBuild:UpdateDesignTimeXaml</Generator>
</EmbeddedResource>
</ItemGroup>
<ItemGroup>
- <EmbeddedResource Include="Call\Controls\CallHandlingPanel.xaml">
+ <EmbeddedResource Include="Call\View\Controls\CallHandlingPanel.xaml">
<Generator>MSBuild:UpdateDesignTimeXaml</Generator>
</EmbeddedResource>
</ItemGroup>
<ItemGroup>
- <EmbeddedResource Include="Call\Controls\ProximityControl.xaml">
+ <EmbeddedResource Include="Call\View\Controls\ProximityControl.xaml">
<Generator>MSBuild:UpdateDesignTimeXaml</Generator>
</EmbeddedResource>
</ItemGroup>
<ItemGroup>
- <EmbeddedResource Include="Call\Controls\RejectCallPanel.xaml">
+ <EmbeddedResource Include="Call\View\Controls\RejectCallPanel.xaml">
<Generator>MSBuild:UpdateDesignTimeXaml</Generator>
</EmbeddedResource>
</ItemGroup>
<ItemGroup>
- <EmbeddedResource Include="Call\Controls\ContactInfoPanel.xaml">
+ <EmbeddedResource Include="Call\View\Controls\ContactInfoPanel.xaml">
<Generator>MSBuild:UpdateDesignTimeXaml</Generator>
</EmbeddedResource>
</ItemGroup>
<ItemGroup>
- <EmbeddedResource Include="Call\Controls\ConferenceCallManageList.xaml">
+ <EmbeddedResource Include="Call\View\Controls\ConferenceCallManageList.xaml">
+ <Generator>MSBuild:UpdateDesignTimeXaml</Generator>
+ </EmbeddedResource>
+ <EmbeddedResource Include="Call\View\ConferenceCallManagePage.xaml">
<Generator>MSBuild:UpdateDesignTimeXaml</Generator>
</EmbeddedResource>
- <EmbeddedResource Include="Call\Pages\ConferenceCallManagePage.xaml">
+ </ItemGroup>
+ <ItemGroup>
+ <EmbeddedResource Include="Call\View\Controls\RejectMessageList.xaml">
<Generator>MSBuild:UpdateDesignTimeXaml</Generator>
</EmbeddedResource>
</ItemGroup>
<ItemGroup>
- <EmbeddedResource Include="Call\Controls\RejectMessageList.xaml">
+ <EmbeddedResource Include="Call\View\Controls\MergeSwapPanel.xaml">
<Generator>MSBuild:UpdateDesignTimeXaml</Generator>
</EmbeddedResource>
</ItemGroup>
<ItemGroup>
- <EmbeddedResource Include="Call\Controls\MergeSwapPanel.xaml">
+ <EmbeddedResource Include="Call\View\Controls\Keypad.xaml">
<Generator>MSBuild:UpdateDesignTimeXaml</Generator>
</EmbeddedResource>
</ItemGroup>
<ItemGroup>
- <EmbeddedResource Include="Call\Controls\Keypad.xaml">
+ <EmbeddedResource Include="Call\View\Controls\KeypadButton.xaml">
<Generator>MSBuild:UpdateDesignTimeXaml</Generator>
</EmbeddedResource>
</ItemGroup>
<ItemGroup>
- <EmbeddedResource Include="Call\Controls\KeypadButton.xaml">
+ <EmbeddedResource Include="Call\View\Controls\MiniActiveCallPanel.xaml">
<Generator>MSBuild:UpdateDesignTimeXaml</Generator>
</EmbeddedResource>
</ItemGroup>
<ItemGroup>
- <EmbeddedResource Include="Call\Controls\MiniActiveCallPanel.xaml">
+ <EmbeddedResource Include="App.xaml">
<Generator>MSBuild:UpdateDesignTimeXaml</Generator>
</EmbeddedResource>
</ItemGroup>
diff --git a/CallApp.Tizen/Common/Themes/CommonTheme.xaml b/CallApp.Tizen/Common/Themes/CommonTheme.xaml
new file mode 100644
index 0000000..bfe445b
--- /dev/null
+++ b/CallApp.Tizen/Common/Themes/CommonTheme.xaml
@@ -0,0 +1,15 @@
+<?xml version="1.0" encoding="utf-8" ?>
+<ResourceDictionary xmlns="http://xamarin.com/schemas/2014/forms"
+ xmlns:x="http://schemas.microsoft.com/winfx/2009/xaml"
+ x:Class="CallApp.Tizen.Common.Themes.CommonTheme">
+
+ <Color x:Key="BGColor">#FFF7F7F7</Color>
+ <Color x:Key="DefaultTextColor">#FFFAFAFA</Color>
+
+ <Color x:Key="CircleButtonAcceptNormalColor">#FF59B03A</Color>
+ <Color x:Key="CircleButtonAcceptPressColor">#FF268035</Color>
+
+ <Color x:Key="CircleButtonRejectBGColor">#4DE02222</Color>
+ <Color x:Key="CircleButtonRejectNormalColor">#FFD63131</Color>
+ <Color x:Key="CircleButtonRejectPressColor">#FFA32626</Color>
+</ResourceDictionary> \ No newline at end of file
diff --git a/CallApp.Tizen/Properties/AssemblyInfo.cs b/CallApp.Tizen/Properties/AssemblyInfo.cs
index 73a9ffc..07bfb7e 100644
--- a/CallApp.Tizen/Properties/AssemblyInfo.cs
+++ b/CallApp.Tizen/Properties/AssemblyInfo.cs
@@ -4,12 +4,12 @@ using System.Runtime.InteropServices;
// General Information about an assembly is controlled through the following
// set of attributes. Change these attribute values to modify the information
// associated with an assembly.
-[assembly: AssemblyTitle("CallApp.Tizen")]
+[assembly: AssemblyTitle("Call")]
[assembly: AssemblyDescription("")]
[assembly: AssemblyConfiguration("")]
-[assembly: AssemblyCompany("")]
-[assembly: AssemblyProduct("CallApp.Tizen")]
-[assembly: AssemblyCopyright("Copyright © 2017")]
+[assembly: AssemblyCompany("Samsung Electronics Co., Ltd")]
+[assembly: AssemblyProduct("Call")]
+[assembly: AssemblyCopyright("Copyright © 2017 Samsung Electronics Co., Ltd")]
[assembly: AssemblyTrademark("")]
[assembly: AssemblyCulture("")]
diff --git a/CallApp.Tizen/Common/Controls/CustomGrid.xaml b/CallApp.Tizen/Tizen.Utility/Controls/CustomGrid.xaml
index c088543..e2112a8 100644
--- a/CallApp.Tizen/Common/Controls/CustomGrid.xaml
+++ b/CallApp.Tizen/Tizen.Utility/Controls/CustomGrid.xaml
@@ -1,7 +1,7 @@
<?xml version="1.0" encoding="utf-8" ?>
<Grid xmlns="http://xamarin.com/schemas/2014/forms"
xmlns:x="http://schemas.microsoft.com/winfx/2009/xaml"
- x:Class="CallApp.Tizen.Common.Controls.CustomGrid"
+ x:Class="Tizen.Utility.Controls.CustomGrid"
ColumnSpacing="0"
RowSpacing="0">
diff --git a/CallApp.Tizen/Common/Controls/CustomGrid.xaml.cs b/CallApp.Tizen/Tizen.Utility/Controls/CustomGrid.xaml.cs
index dafc716..cfe469a 100644
--- a/CallApp.Tizen/Common/Controls/CustomGrid.xaml.cs
+++ b/CallApp.Tizen/Tizen.Utility/Controls/CustomGrid.xaml.cs
@@ -16,7 +16,7 @@
using Xamarin.Forms;
-namespace CallApp.Tizen.Common.Controls
+namespace Tizen.Utility.Controls
{
/// <summary>
/// Extension of Xamarin Grid, with support:
diff --git a/CallApp.Tizen/Common/Controls/CustomImage.xaml b/CallApp.Tizen/Tizen.Utility/Controls/CustomImage.xaml
index 9f3432c..a9623de 100644
--- a/CallApp.Tizen/Common/Controls/CustomImage.xaml
+++ b/CallApp.Tizen/Tizen.Utility/Controls/CustomImage.xaml
@@ -1,6 +1,6 @@
<?xml version="1.0" encoding="utf-8" ?>
<Image xmlns="http://xamarin.com/schemas/2014/forms"
xmlns:x="http://schemas.microsoft.com/winfx/2009/xaml"
- x:Class="CallApp.Tizen.Common.Controls.CustomImage">
+ x:Class="Tizen.Utility.Controls.CustomImage">
</Image> \ No newline at end of file
diff --git a/CallApp.Tizen/Common/Controls/CustomImage.xaml.cs b/CallApp.Tizen/Tizen.Utility/Controls/CustomImage.xaml.cs
index ca1721e..f905440 100644
--- a/CallApp.Tizen/Common/Controls/CustomImage.xaml.cs
+++ b/CallApp.Tizen/Tizen.Utility/Controls/CustomImage.xaml.cs
@@ -16,7 +16,7 @@
using Xamarin.Forms;
-namespace CallApp.Tizen.Common.Controls
+namespace Tizen.Utility.Controls
{
/// <summary>
/// Extension of Xamarin Image, with support:
diff --git a/CallApp.Tizen/Common/Controls/GesturesContainer.xaml b/CallApp.Tizen/Tizen.Utility/Controls/GesturesContainer.xaml
index 210face..31389a3 100644
--- a/CallApp.Tizen/Common/Controls/GesturesContainer.xaml
+++ b/CallApp.Tizen/Tizen.Utility/Controls/GesturesContainer.xaml
@@ -1,6 +1,6 @@
<?xml version="1.0" encoding="UTF-8"?>
<ContentView xmlns="http://xamarin.com/schemas/2014/forms"
xmlns:x="http://schemas.microsoft.com/winfx/2009/xaml"
- x:Class="CallApp.Tizen.Common.Controls.GesturesContainer">
+ x:Class="Tizen.Utility.Controls.GesturesContainer">
</ContentView> \ No newline at end of file
diff --git a/CallApp.Tizen/Common/Controls/GesturesContainer.xaml.cs b/CallApp.Tizen/Tizen.Utility/Controls/GesturesContainer.xaml.cs
index 5a0b303..63a6038 100644
--- a/CallApp.Tizen/Common/Controls/GesturesContainer.xaml.cs
+++ b/CallApp.Tizen/Tizen.Utility/Controls/GesturesContainer.xaml.cs
@@ -17,7 +17,7 @@
using System;
using Xamarin.Forms;
-namespace CallApp.Tizen.Common.Controls
+namespace Tizen.Utility.Controls
{
/// <summary>
/// Container that performs freeform gestures. Can be wrapped around UI element
diff --git a/CallApp.Tizen/Common/Controls/Renderers/CustomImageRenderer.cs b/CallApp.Tizen/Tizen.Utility/Controls/Renderers/CustomImageRenderer.cs
index 564ff20..183c971 100644
--- a/CallApp.Tizen/Common/Controls/Renderers/CustomImageRenderer.cs
+++ b/CallApp.Tizen/Tizen.Utility/Controls/Renderers/CustomImageRenderer.cs
@@ -14,14 +14,14 @@
* limitations under the License.
*/
-using CallApp.Tizen.Common.Controls;
-using CallApp.Tizen.Common.Controls.Renderers;
using System.ComponentModel;
+using Tizen.Utility.Controls;
+using Tizen.Utility.Controls.Renderers;
using Xamarin.Forms;
using Xamarin.Forms.Platform.Tizen;
[assembly: ExportRenderer(typeof(CustomImage), typeof(CustomImageRenderer))]
-namespace CallApp.Tizen.Common.Controls.Renderers
+namespace Tizen.Utility.Controls.Renderers
{
/// <summary>
/// A renderer for CustomImage
diff --git a/CallApp.Tizen/Common/Converters/IsNullConverter.cs b/CallApp.Tizen/Tizen.Utility/Converters/IsNullConverter.cs
index 4199cc5..10dbf4c 100644
--- a/CallApp.Tizen/Common/Converters/IsNullConverter.cs
+++ b/CallApp.Tizen/Tizen.Utility/Converters/IsNullConverter.cs
@@ -18,7 +18,7 @@ using System;
using System.Globalization;
using Xamarin.Forms;
-namespace CallApp.Tizen.Common.Converters
+namespace Tizen.Utility.Converters
{
class IsNullConverter : IValueConverter
{
diff --git a/CallApp.Tizen/Common/Converters/IsStringEmptyConverter.cs b/CallApp.Tizen/Tizen.Utility/Converters/IsStringEmptyConverter.cs
index b7915a4..a33c946 100644
--- a/CallApp.Tizen/Common/Converters/IsStringEmptyConverter.cs
+++ b/CallApp.Tizen/Tizen.Utility/Converters/IsStringEmptyConverter.cs
@@ -18,7 +18,7 @@ using System;
using System.Globalization;
using Xamarin.Forms;
-namespace CallApp.Tizen.Common.Converters
+namespace Tizen.Utility.Converters
{
class IsStringEmptyConverter : IValueConverter
{
diff --git a/CallApp.Tizen/Common/Helpers/BaseModel.cs b/CallApp.Tizen/Tizen.Utility/Helpers/BaseModel.cs
index 137ca91..b622fce 100644
--- a/CallApp.Tizen/Common/Helpers/BaseModel.cs
+++ b/CallApp.Tizen/Tizen.Utility/Helpers/BaseModel.cs
@@ -17,7 +17,7 @@
using System.ComponentModel;
using System.Runtime.CompilerServices;
-namespace CallApp.Tizen.Common.Helpers
+namespace Tizen.Utility.Helpers
{
/// <summary>
/// Base class for ViewModels or Models, implements INotifyPropertyChanged interface
diff --git a/CallApp.Tizen/Common/Helpers/Logger.cs b/CallApp.Tizen/Tizen.Utility/Helpers/Logger.cs
index 8aa8838..9df9bca 100644
--- a/CallApp.Tizen/Common/Helpers/Logger.cs
+++ b/CallApp.Tizen/Tizen.Utility/Helpers/Logger.cs
@@ -17,7 +17,7 @@
using System;
using System.Runtime.CompilerServices;
-namespace CallApp.Tizen.Common.Helpers
+namespace Tizen.Utility.Helpers
{
static class Logger
{
diff --git a/CallApp.Tizen/Common/Helpers/PageNavigator.cs b/CallApp.Tizen/Tizen.Utility/Helpers/PageNavigator.cs
index 3ccc54f..0b46f57 100644
--- a/CallApp.Tizen/Common/Helpers/PageNavigator.cs
+++ b/CallApp.Tizen/Tizen.Utility/Helpers/PageNavigator.cs
@@ -16,7 +16,7 @@
using Xamarin.Forms;
-namespace CallApp.Tizen.Common.Helpers
+namespace Tizen.Utility.Helpers
{
/// <summary>
/// Helper with navigation logics through pages
diff --git a/CallApp.Tizen/Common/Input/AttachedTapCommand.cs b/CallApp.Tizen/Tizen.Utility/Input/AttachedTapCommand.cs
index 5da94d2..e65c4eb 100644
--- a/CallApp.Tizen/Common/Input/AttachedTapCommand.cs
+++ b/CallApp.Tizen/Tizen.Utility/Input/AttachedTapCommand.cs
@@ -14,10 +14,11 @@
* limitations under the License.
*/
+using System;
using System.Windows.Input;
using Xamarin.Forms;
-namespace CallApp.Tizen.Common.Input
+namespace Tizen.Utility.Input
{
/// <summary>
/// Implementation of tap event through command. Can be attached to UI control
@@ -77,7 +78,7 @@ namespace CallApp.Tizen.Common.Input
return null;
}
- private static void OnTapped(object sender, System.EventArgs e)
+ private static void OnTapped(object sender, EventArgs e)
{
if (sender is BindableObject obj)
{
diff --git a/CallApp.Tizen/Common/Input/GesturesInput.cs b/CallApp.Tizen/Tizen.Utility/Input/GesturesInput.cs
index ec1ce10..c8c75b4 100644
--- a/CallApp.Tizen/Common/Input/GesturesInput.cs
+++ b/CallApp.Tizen/Tizen.Utility/Input/GesturesInput.cs
@@ -17,7 +17,7 @@
using Tizen.Xamarin.Forms.Extension;
using Xamarin.Forms;
-namespace CallApp.Tizen.Common.Input
+namespace Tizen.Utility.Input
{
/// <summary>
/// Extension for supporting Gestures in Triggers
diff --git a/CallApp.Tizen/loc/loc.Designer.cs b/CallApp.Tizen/loc/Localization.Designer.cs
index ba28dd8..42de47e 100644
--- a/CallApp.Tizen/loc/loc.Designer.cs
+++ b/CallApp.Tizen/loc/Localization.Designer.cs
@@ -8,10 +8,11 @@
// </auto-generated>
//------------------------------------------------------------------------------
-namespace CallApp.Tizen.loc {
+namespace CallApp.Tizen.Localization
+{
using System;
-
-
+
+
/// <summary>
/// A strongly-typed resource class, for looking up localized strings, etc.
/// </summary>
@@ -22,238 +23,290 @@ namespace CallApp.Tizen.loc {
[global::System.CodeDom.Compiler.GeneratedCodeAttribute("System.Resources.Tools.StronglyTypedResourceBuilder", "4.0.0.0")]
[global::System.Diagnostics.DebuggerNonUserCodeAttribute()]
[global::System.Runtime.CompilerServices.CompilerGeneratedAttribute()]
- public class loc {
-
+ public class Localization
+ {
+
private static global::System.Resources.ResourceManager resourceMan;
-
+
private static global::System.Globalization.CultureInfo resourceCulture;
-
+
[global::System.Diagnostics.CodeAnalysis.SuppressMessageAttribute("Microsoft.Performance", "CA1811:AvoidUncalledPrivateCode")]
- internal loc() {
+ internal Localization()
+ {
}
-
+
/// <summary>
/// Returns the cached ResourceManager instance used by this class.
/// </summary>
[global::System.ComponentModel.EditorBrowsableAttribute(global::System.ComponentModel.EditorBrowsableState.Advanced)]
- public static global::System.Resources.ResourceManager ResourceManager {
- get {
- if (object.ReferenceEquals(resourceMan, null)) {
- global::System.Resources.ResourceManager temp = new global::System.Resources.ResourceManager("CallApp.Tizen.loc.loc", typeof(loc).Assembly);
+ public static global::System.Resources.ResourceManager ResourceManager
+ {
+ get
+ {
+ if (object.ReferenceEquals(resourceMan, null))
+ {
+ global::System.Resources.ResourceManager temp = new global::System.Resources.ResourceManager("CallApp.Tizen.loc.Localization", typeof(Localization).Assembly);
resourceMan = temp;
}
return resourceMan;
}
}
-
+
/// <summary>
/// Overrides the current thread's CurrentUICulture property for all
/// resource lookups using this strongly typed resource class.
/// </summary>
[global::System.ComponentModel.EditorBrowsableAttribute(global::System.ComponentModel.EditorBrowsableState.Advanced)]
- public static global::System.Globalization.CultureInfo Culture {
- get {
+ public static global::System.Globalization.CultureInfo Culture
+ {
+ get
+ {
return resourceCulture;
}
- set {
+ set
+ {
resourceCulture = value;
}
}
-
+
/// <summary>
/// Looks up a localized string similar to Add call.
/// </summary>
- public static string AddCall {
- get {
+ public static string AddCall
+ {
+ get
+ {
return ResourceManager.GetString("AddCall", resourceCulture);
}
}
-
+
/// <summary>
/// Looks up a localized string similar to Bluetooth.
/// </summary>
- public static string Bluetooth {
- get {
+ public static string Bluetooth
+ {
+ get
+ {
return ResourceManager.GetString("Bluetooth", resourceCulture);
}
}
-
+
/// <summary>
/// Looks up a localized string similar to Call back.
/// </summary>
- public static string CallBack {
- get {
+ public static string CallBack
+ {
+ get
+ {
return ResourceManager.GetString("CallBack", resourceCulture);
}
}
-
+
/// <summary>
/// Looks up a localized string similar to Sorry, I&apos;m busy. Call you later..
/// </summary>
- public static string CallYouLaterRejectMessage {
- get {
+ public static string CallYouLaterRejectMessage
+ {
+ get
+ {
return ResourceManager.GetString("CallYouLaterRejectMessage", resourceCulture);
}
}
-
+
/// <summary>
/// Looks up a localized string similar to Compose message to send.
/// </summary>
- public static string ComposeMessageToSend {
- get {
+ public static string ComposeMessageToSend
+ {
+ get
+ {
return ResourceManager.GetString("ComposeMessageToSend", resourceCulture);
}
}
-
+
/// <summary>
/// Looks up a localized string similar to Contacts.
/// </summary>
- public static string Contacts {
- get {
+ public static string Contacts
+ {
+ get
+ {
return ResourceManager.GetString("Contacts", resourceCulture);
}
}
-
+
/// <summary>
/// Looks up a localized string similar to Dialling....
/// </summary>
- public static string Dialling {
- get {
+ public static string Dialling
+ {
+ get
+ {
return ResourceManager.GetString("Dialling", resourceCulture);
}
}
-
+
/// <summary>
/// Looks up a localized string similar to Sorry, I&apos;m driving now..
/// </summary>
- public static string DrivingNowRejectMessage {
- get {
+ public static string DrivingNowRejectMessage
+ {
+ get
+ {
return ResourceManager.GetString("DrivingNowRejectMessage", resourceCulture);
}
}
-
+
/// <summary>
/// Looks up a localized string similar to Call ended.
/// </summary>
- public static string EndCall {
- get {
+ public static string EndCall
+ {
+ get
+ {
return ResourceManager.GetString("EndCall", resourceCulture);
}
}
-
+
/// <summary>
/// Looks up a localized string similar to Incoming call.
/// </summary>
- public static string IncomingCall {
- get {
+ public static string IncomingCall
+ {
+ get
+ {
return ResourceManager.GetString("IncomingCall", resourceCulture);
}
}
-
+
/// <summary>
/// Looks up a localized string similar to I&apos;m in a meeting..
/// </summary>
- public static string InMeetingRejectMessage {
- get {
+ public static string InMeetingRejectMessage
+ {
+ get
+ {
return ResourceManager.GetString("InMeetingRejectMessage", resourceCulture);
}
}
-
+
/// <summary>
/// Looks up a localized string similar to Keypad.
/// </summary>
- public static string Keypad {
- get {
+ public static string Keypad
+ {
+ get
+ {
return ResourceManager.GetString("Keypad", resourceCulture);
}
}
-
+
/// <summary>
/// Looks up a localized string similar to Merge.
/// </summary>
- public static string Merge {
- get {
+ public static string Merge
+ {
+ get
+ {
return ResourceManager.GetString("Merge", resourceCulture);
}
}
-
+
/// <summary>
/// Looks up a localized string similar to Message.
/// </summary>
- public static string Message {
- get {
+ public static string Message
+ {
+ get
+ {
return ResourceManager.GetString("Message", resourceCulture);
}
}
-
+
/// <summary>
/// Looks up a localized string similar to Mute.
/// </summary>
- public static string Mute {
- get {
+ public static string Mute
+ {
+ get
+ {
return ResourceManager.GetString("Mute", resourceCulture);
}
}
-
+
/// <summary>
/// Looks up a localized string similar to On hold.
/// </summary>
- public static string OnHold {
- get {
+ public static string OnHold
+ {
+ get
+ {
return ResourceManager.GetString("OnHold", resourceCulture);
}
}
-
+
/// <summary>
/// Looks up a localized string similar to Sorry, I&apos;m busy. Please text me..
/// </summary>
- public static string PleaseTextMeRejectMessage {
- get {
+ public static string PleaseTextMeRejectMessage
+ {
+ get
+ {
return ResourceManager.GetString("PleaseTextMeRejectMessage", resourceCulture);
}
}
-
+
/// <summary>
/// Looks up a localized string similar to Reject call with message.
/// </summary>
- public static string RejectCallWithMessage {
- get {
+ public static string RejectCallWithMessage
+ {
+ get
+ {
return ResourceManager.GetString("RejectCallWithMessage", resourceCulture);
}
}
-
+
/// <summary>
/// Looks up a localized string similar to Return to call screen.
/// </summary>
- public static string ReturnToCallScreen {
- get {
+ public static string ReturnToCallScreen
+ {
+ get
+ {
return ResourceManager.GetString("ReturnToCallScreen", resourceCulture);
}
}
-
+
/// <summary>
/// Looks up a localized string similar to Speaker.
/// </summary>
- public static string Speaker {
- get {
+ public static string Speaker
+ {
+ get
+ {
return ResourceManager.GetString("Speaker", resourceCulture);
}
}
-
+
/// <summary>
/// Looks up a localized string similar to Swap.
/// </summary>
- public static string Swap {
- get {
+ public static string Swap
+ {
+ get
+ {
return ResourceManager.GetString("Swap", resourceCulture);
}
}
-
+
/// <summary>
/// Looks up a localized string similar to I can&apos;t talk now. What&apos;s up?.
/// </summary>
- public static string WhatsUpRejectMessage {
- get {
+ public static string WhatsUpRejectMessage
+ {
+ get
+ {
return ResourceManager.GetString("WhatsUpRejectMessage", resourceCulture);
}
}
diff --git a/CallApp.Tizen/loc/loc.resx b/CallApp.Tizen/loc/Localization.resx
index 4bc6838..4bc6838 100644
--- a/CallApp.Tizen/loc/loc.resx
+++ b/CallApp.Tizen/loc/Localization.resx
diff --git a/CallApp.Tizen/res/Call ID/168x168/call_end_photo_id_default.png b/CallApp.Tizen/res/Call ID/168x168/call_end_photo_id_default.png
deleted file mode 100644
index df1d754..0000000
--- a/CallApp.Tizen/res/Call ID/168x168/call_end_photo_id_default.png
+++ /dev/null
Binary files differ
diff --git a/CallApp.Tizen/res/Call ID/348x348/call_photo_id.png b/CallApp.Tizen/res/Call ID/348x348/call_photo_id.png
deleted file mode 100644
index ebdee4a..0000000
--- a/CallApp.Tizen/res/Call ID/348x348/call_photo_id.png
+++ /dev/null
Binary files differ
diff --git a/CallApp.Tizen/res/Call ID/348x348/call_photo_id_conference.png b/CallApp.Tizen/res/Call ID/348x348/call_photo_id_conference.png
deleted file mode 100644
index 87ca480..0000000
--- a/CallApp.Tizen/res/Call ID/348x348/call_photo_id_conference.png
+++ /dev/null
Binary files differ
diff --git a/CallApp.Tizen/res/Call ID/96x96/call_photo_id_conference.png b/CallApp.Tizen/res/Call ID/96x96/call_photo_id_conference.png
deleted file mode 100644
index 8974cfc..0000000
--- a/CallApp.Tizen/res/Call ID/96x96/call_photo_id_conference.png
+++ /dev/null
Binary files differ
diff --git a/CallApp.Tizen/res/call_manage_photo_id_mask_04.png b/CallApp.Tizen/res/call_manage_photo_id_mask_04.png
deleted file mode 100644
index a640189..0000000
--- a/CallApp.Tizen/res/call_manage_photo_id_mask_04.png
+++ /dev/null
Binary files differ
diff --git a/CallApp.Tizen/Call/Themes/CallTheme.xaml.cs b/CallApp.Tizen/Common/Themes/CommonTheme.xaml.cs
index 4d2854a..96b74f1 100644
--- a/CallApp.Tizen/Call/Themes/CallTheme.xaml.cs
+++ b/CallApp.Tizen/Common/Themes/CommonTheme.xaml.cs
@@ -16,14 +16,14 @@
using Xamarin.Forms;
-namespace CallApp.Tizen.Call.Themes
+namespace CallApp.Tizen.Common.Themes
{
/// <summary>
/// Partial class of CallTheme.xaml
/// </summary>
- public partial class CallTheme : ResourceDictionary
+ public partial class CommonTheme : ResourceDictionary
{
- public CallTheme()
+ public CommonTheme()
{
InitializeComponent();
}
@@ -16,14 +16,14 @@
{
/// <summary>
- /// Partial class of CallTheme.xaml
+ /// Partial class of CommonTheme.xaml
/// </summary>